Class: Google::Apis::VmwareengineV1::AcceleratePrivateCloudDeletionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Request message for VmwareEngine.AcceleratePrivateCloudDeletion

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AcceleratePrivateCloudDeletionRequest

Returns a new instance of AcceleratePrivateCloudDeletionRequest.



43
44
45
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 43

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. Checksum used to ensure that the user-provided value is up to date before the server processes the request. The server compares provided checksum with the current checksum of the resource. If the user-provided value is out of date, this request returns an ABORTED error. Corresponds to the JSON property etag

Returns:

  • (String)


35
36
37
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 35

def etag
  @etag
end

#request_idString

Optional. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


41
42
43
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 41

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48
49
50
51
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 48

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @request_id = args[:request_id] if args.key?(:request_id)
end