Class: Google::Apis::VmwareengineV1::Datastore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Represents a datastore resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Datastore

Returns a new instance of Datastore.



630
631
632
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 630

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clustersArray<String>

Output only. Clusters to which the datastore is attached. Corresponds to the JSON property clusters

Returns:

  • (Array<String>)


582
583
584
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 582

def clusters
  @clusters
end

#create_timeString

Output only. Creation time of this resource. Corresponds to the JSON property createTime

Returns:

  • (String)


587
588
589
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 587

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description for this datastore Corresponds to the JSON property description

Returns:

  • (String)


592
593
594
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 592

def description
  @description
end

#etagString

Optional. Checksum that may be sent on update and delete requests to ensure that the user-provided value is up to date before the server processes a request. The server computes checksums based on the value of other fields in the request. Corresponds to the JSON property etag

Returns:

  • (String)


600
601
602
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 600

def etag
  @etag
end

#nameString

Output only. Identifier. The resource name of this datastore. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/ apis/design/resource_names. For example: projects/my-project/locations/us- central1/datastores/datastore Corresponds to the JSON property name

Returns:

  • (String)


608
609
610
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 608

def name
  @name
end

#nfs_datastoreGoogle::Apis::VmwareengineV1::NfsDatastore

The NFS datastore configuration. Corresponds to the JSON property nfsDatastore



613
614
615
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 613

def nfs_datastore
  @nfs_datastore
end

#stateString

Output only. The state of the Datastore. Corresponds to the JSON property state

Returns:

  • (String)


618
619
620
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 618

def state
  @state
end

#uidString

Output only. System-generated unique identifier for the resource. Corresponds to the JSON property uid

Returns:

  • (String)


623
624
625
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 623

def uid
  @uid
end

#update_timeString

Output only. Last update time of this resource. Corresponds to the JSON property updateTime

Returns:

  • (String)


628
629
630
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 628

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



635
636
637
638
639
640
641
642
643
644
645
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 635

def update!(**args)
  @clusters = args[:clusters] if args.key?(:clusters)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @nfs_datastore = args[:nfs_datastore] if args.key?(:nfs_datastore)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end