Class: Google::Apis::VmwareengineV1::DatastoreNetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

The network configuration for the datastore.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatastoreNetwork

Returns a new instance of DatastoreNetwork.



744
745
746
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_countFixnum

Optional. connection_count is used to set multiple connections from NFS client on ESXi host to NFS server. A higher number of connections results in better performance on datastores. In MountDatastore API by default max 4 connections are configured. User can set value of connection_count between 1 to 4. Connection_count is supported from vsphere 8.0u1 for earlier version 1 connection count is set on the ESXi hosts. Corresponds to the JSON property connectionCount

Returns:

  • (Fixnum)


715
716
717
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 715

def connection_count
  @connection_count
end

#mtuFixnum

Optional. MTU value is set on the VMKernel adapter for the NFS traffic. By default standard 1500 MTU size is set in MountDatastore API which is good for typical setups. However google VPC networks supports jumbo MTU 8896. We recommend to tune this value based on the NFS traffic performance. Performance can be determined using benchmarking I/O tools like fio (Flexible I/O Tester) utility. Corresponds to the JSON property mtu

Returns:

  • (Fixnum)


725
726
727
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 725

def mtu
  @mtu
end

#network_peeringString

Output only. The resource name of the network peering, used to access the file share by clients on private cloud. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/resource_names. e.g. projects/my-project/locations/us-central1/networkPeerings/my-network- peering Corresponds to the JSON property networkPeering

Returns:

  • (String)


734
735
736
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 734

def network_peering
  @network_peering
end

#subnetString

Required. The resource name of the subnet Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/ resource_names. e.g. projects/my-project/locations/us-central1/subnets/my- subnet Corresponds to the JSON property subnet

Returns:

  • (String)


742
743
744
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 742

def subnet
  @subnet
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



749
750
751
752
753
754
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 749

def update!(**args)
  @connection_count = args[:connection_count] if args.key?(:connection_count)
  @mtu = args[:mtu] if args.key?(:mtu)
  @network_peering = args[:network_peering] if args.key?(:network_peering)
  @subnet = args[:subnet] if args.key?(:subnet)
end