Class: Google::Apis::VmwareengineV1::ListClustersResponse
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::ListClustersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Response message for VmwareEngine.ListClusters
Instance Attribute Summary collapse
-
#clusters ⇒ Array<Google::Apis::VmwareengineV1::Cluster>
A list of private cloud clusters.
-
#next_page_token ⇒ String
A token, which can be sent as
page_tokento retrieve the next page. -
#unreachable ⇒ Array<String>
Locations that could not be reached when making an aggregated query using wildcards.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListClustersResponse
constructor
A new instance of ListClustersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListClustersResponse
Returns a new instance of ListClustersResponse.
1449 1450 1451 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1449 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clusters ⇒ Array<Google::Apis::VmwareengineV1::Cluster>
A list of private cloud clusters.
Corresponds to the JSON property clusters
1435 1436 1437 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1435 def clusters @clusters end |
#next_page_token ⇒ String
A token, which can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
1441 1442 1443 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1441 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached when making an aggregated query using
wildcards.
Corresponds to the JSON property unreachable
1447 1448 1449 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1447 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1454 1455 1456 1457 1458 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1454 def update!(**args) @clusters = args[:clusters] if args.key?(:clusters) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |