Class: Google::Apis::VmwareengineV1::ListHcxActivationKeysResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Response message for VmwareEngine.ListHcxActivationKeys

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListHcxActivationKeysResponse

Returns a new instance of ListHcxActivationKeysResponse.



1580
1581
1582
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1580

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hcx_activation_keysArray<Google::Apis::VmwareengineV1::HcxActivationKey>

List of HCX activation keys. Corresponds to the JSON property hcxActivationKeys



1566
1567
1568
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1566

def hcx_activation_keys
  @hcx_activation_keys
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1572
1573
1574
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1572

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached when making an aggregated query using wildcards. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1578
1579
1580
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1578

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1585
1586
1587
1588
1589
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1585

def update!(**args)
  @hcx_activation_keys = args[:hcx_activation_keys] if args.key?(:hcx_activation_keys)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end