Class: Google::Apis::VmwareengineV1::ListLoggingServersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Response message for VmwareEngine.ListLoggingServers

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListLoggingServersResponse

Returns a new instance of ListLoggingServersResponse.



1638
1639
1640
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1638

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#logging_serversArray<Google::Apis::VmwareengineV1::LoggingServer>

A list of Logging Servers. Corresponds to the JSON property loggingServers



1624
1625
1626
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1624

def logging_servers
  @logging_servers
end

#next_page_tokenString

A token, which can be send as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1630
1631
1632
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1630

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached when making an aggregated query using wildcards. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1636
1637
1638
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1636

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1643
1644
1645
1646
1647
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1643

def update!(**args)
  @logging_servers = args[:logging_servers] if args.key?(:logging_servers)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end