Class: Google::Apis::VmwareengineV1::ListNetworkPoliciesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Response message for VmwareEngine.ListNetworkPolicies

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListNetworkPoliciesResponse

Returns a new instance of ListNetworkPoliciesResponse.



1706
1707
1708
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_policiesArray<Google::Apis::VmwareengineV1::NetworkPolicy>

A list of network policies. Corresponds to the JSON property networkPolicies



1692
1693
1694
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1692

def network_policies
  @network_policies
end

#next_page_tokenString

A token, which can be send as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1698
1699
1700
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1698

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached when making an aggregated query using wildcards. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1704
1705
1706
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1704

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1711
1712
1713
1714
1715
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1711

def update!(**args)
  @network_policies = args[:network_policies] if args.key?(:network_policies)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end