Class: Google::Apis::VmwareengineV1::ListPrivateCloudsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Response message for VmwareEngine.ListPrivateClouds

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPrivateCloudsResponse

Returns a new instance of ListPrivateCloudsResponse.



1888
1889
1890
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1875
1876
1877
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1875

def next_page_token
  @next_page_token
end

#private_cloudsArray<Google::Apis::VmwareengineV1::PrivateCloud>

A list of private clouds. Corresponds to the JSON property privateClouds



1880
1881
1882
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1880

def private_clouds
  @private_clouds
end

#unreachableArray<String>

Locations that could not be reached when making an aggregated query using wildcards. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1886
1887
1888
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1886

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1893
1894
1895
1896
1897
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1893

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @private_clouds = args[:private_clouds] if args.key?(:private_clouds)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end