Class: Google::Apis::VmwareengineV1::ListSubnetsResponse
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::ListSubnetsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Response message for VmwareEngine.ListSubnets
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token, which can be sent as
page_tokento retrieve the next page. -
#subnets ⇒ Array<Google::Apis::VmwareengineV1::Subnet>
A list of subnets.
-
#unreachable ⇒ Array<String>
Locations that could not be reached when making an aggregated query using wildcards.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSubnetsResponse
constructor
A new instance of ListSubnetsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSubnetsResponse
Returns a new instance of ListSubnetsResponse.
1979 1980 1981 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1979 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token, which can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
1966 1967 1968 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1966 def next_page_token @next_page_token end |
#subnets ⇒ Array<Google::Apis::VmwareengineV1::Subnet>
A list of subnets.
Corresponds to the JSON property subnets
1971 1972 1973 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1971 def subnets @subnets end |
#unreachable ⇒ Array<String>
Locations that could not be reached when making an aggregated query using
wildcards.
Corresponds to the JSON property unreachable
1977 1978 1979 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1977 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1984 1985 1986 1987 1988 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1984 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @subnets = args[:subnets] if args.key?(:subnets) @unreachable = args[:unreachable] if args.key?(:unreachable) end |