Class: Google::Apis::VmwareengineV1::LoggingServer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Logging server to receive vCenter or ESXi logs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoggingServer

Returns a new instance of LoggingServer.



2172
2173
2174
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Creation time of this resource. Corresponds to the JSON property createTime

Returns:

  • (String)


2130
2131
2132
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2130

def create_time
  @create_time
end

#hostnameString

Required. Fully-qualified domain name (FQDN) or IP Address of the logging server. Corresponds to the JSON property hostname

Returns:

  • (String)


2136
2137
2138
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2136

def hostname
  @hostname
end

#nameString

Output only. The resource name of this logging server. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/ design/resource_names. For example: projects/my-project/locations/us-central1- a/privateClouds/my-cloud/loggingServers/my-logging-server Corresponds to the JSON property name

Returns:

  • (String)


2144
2145
2146
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2144

def name
  @name
end

#portFixnum

Required. Port number at which the logging server receives logs. Corresponds to the JSON property port

Returns:

  • (Fixnum)


2149
2150
2151
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2149

def port
  @port
end

#protocolString

Required. Protocol used by vCenter to send logs to a logging server. Corresponds to the JSON property protocol

Returns:

  • (String)


2154
2155
2156
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2154

def protocol
  @protocol
end

#source_typeString

Required. The type of component that produces logs that will be forwarded to this logging server. Corresponds to the JSON property sourceType

Returns:

  • (String)


2160
2161
2162
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2160

def source_type
  @source_type
end

#uidString

Output only. System-generated unique identifier for the resource. Corresponds to the JSON property uid

Returns:

  • (String)


2165
2166
2167
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2165

def uid
  @uid
end

#update_timeString

Output only. Last update time of this resource. Corresponds to the JSON property updateTime

Returns:

  • (String)


2170
2171
2172
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2170

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2177

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @hostname = args[:hostname] if args.key?(:hostname)
  @name = args[:name] if args.key?(:name)
  @port = args[:port] if args.key?(:port)
  @protocol = args[:protocol] if args.key?(:protocol)
  @source_type = args[:source_type] if args.key?(:source_type)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end