Class: Google::Apis::VmwareengineV1::ManagementCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Management cluster configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagementCluster

Returns a new instance of ManagementCluster.



2213
2214
2215
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Required. The user-provided identifier of the new Cluster. The identifier must meet the following requirements: * Only contains 1-63 alphanumeric characters and hyphens * Begins with an alphabetical character * Ends with a non-hyphen character * Not formatted as a UUID * Complies with RFC 1034 (section 3.5) Corresponds to the JSON property clusterId

Returns:

  • (String)


2200
2201
2202
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2200

def cluster_id
  @cluster_id
end

#node_type_configsHash<String,Google::Apis::VmwareengineV1::NodeTypeConfig>

Required. The map of cluster node types in this cluster, where the key is canonical identifier of the node type (corresponds to the NodeType). Corresponds to the JSON property nodeTypeConfigs



2206
2207
2208
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2206

def node_type_configs
  @node_type_configs
end

#stretched_cluster_configGoogle::Apis::VmwareengineV1::StretchedClusterConfig

Configuration of a stretched cluster. Corresponds to the JSON property stretchedClusterConfig



2211
2212
2213
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2211

def stretched_cluster_config
  @stretched_cluster_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2218
2219
2220
2221
2222
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2218

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @node_type_configs = args[:node_type_configs] if args.key?(:node_type_configs)
  @stretched_cluster_config = args[:stretched_cluster_config] if args.key?(:stretched_cluster_config)
end