Class: Google::Apis::VmwareengineV1::ManagementDnsZoneBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Represents a binding between a network and the management DNS zone. A management DNS zone is the Cloud DNS cross-project binding zone that VMware Engine creates for each private cloud. It contains FQDNs and corresponding IP addresses for the private cloud's ESXi hosts and management VM appliances like vCenter and NSX Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagementDnsZoneBinding

Returns a new instance of ManagementDnsZoneBinding.



2282
2283
2284
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2282

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Creation time of this resource. Corresponds to the JSON property createTime

Returns:

  • (String)


2236
2237
2238
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2236

def create_time
  @create_time
end

#descriptionString

User-provided description for this resource. Corresponds to the JSON property description

Returns:

  • (String)


2241
2242
2243
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2241

def description
  @description
end

#nameString

Output only. The resource name of this binding. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/ resource_names. For example: projects/my-project/locations/us-central1-a/ privateClouds/my-cloud/managementDnsZoneBindings/my-management-dns-zone- binding Corresponds to the JSON property name

Returns:

  • (String)


2250
2251
2252
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2250

def name
  @name
end

#stateString

Output only. The state of the resource. Corresponds to the JSON property state

Returns:

  • (String)


2255
2256
2257
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2255

def state
  @state
end

#uidString

Output only. System-generated unique identifier for the resource. Corresponds to the JSON property uid

Returns:

  • (String)


2260
2261
2262
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2260

def uid
  @uid
end

#update_timeString

Output only. Last update time of this resource. Corresponds to the JSON property updateTime

Returns:

  • (String)


2265
2266
2267
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2265

def update_time
  @update_time
end

#vmware_engine_networkString

Network to bind is a VMware Engine network. Specify the name in the following form for VMware engine network: projects/project/locations/global/ vmwareEngineNetworks/vmware_engine_network_id.project`can either be a project number or a project ID. Corresponds to the JSON propertyvmwareEngineNetwork`

Returns:

  • (String)


2273
2274
2275
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2273

def vmware_engine_network
  @vmware_engine_network
end

#vpc_networkString

Network to bind is a standard consumer VPC. Specify the name in the following form for consumer VPC network: projects/project/global/networks/network_id . project can either be a project number or a project ID. Corresponds to the JSON property vpcNetwork

Returns:

  • (String)


2280
2281
2282
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2280

def vpc_network
  @vpc_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2287

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vmware_engine_network = args[:vmware_engine_network] if args.key?(:vmware_engine_network)
  @vpc_network = args[:vpc_network] if args.key?(:vpc_network)
end