Class: Google::Apis::VmwareengineV1::MigrateManagementVmsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Request message for VmwareEngine.MigrateManagementVms

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MigrateManagementVmsRequest

Returns a new instance of MigrateManagementVmsRequest.



2335
2336
2337
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2335

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Required. The user-provided identifier of the workload cluster to which the management VMs are to be migrated. The cluster must be in the same private cloud as the one specified in name, and must be a workload cluster. The eventual cluster name will be constructed from the private cloud name and this cluster ID. Corresponds to the JSON property clusterId

Returns:

  • (String)


2310
2311
2312
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2310

def cluster_id
  @cluster_id
end

#etagString

Optional. Checksum used to ensure that the user-provided value is up to date before the server processes the request. The server compares provided checksum with the current checksum of the resource. If the user-provided value is out of date, this request returns an ABORTED error. Corresponds to the JSON property etag

Returns:

  • (String)


2318
2319
2320
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2318

def etag
  @etag
end

#request_idString

Optional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server guarantees that a request doesn't result in creation of duplicate commitments for at least 60 minutes. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if the original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000- 0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


2333
2334
2335
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2333

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2340
2341
2342
2343
2344
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2340

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @etag = args[:etag] if args.key?(:etag)
  @request_id = args[:request_id] if args.key?(:request_id)
end