Class: Google::Apis::VmwareengineV1::MountDatastoreRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Mount Datastore Request message

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MountDatastoreRequest

Returns a new instance of MountDatastoreRequest.



2379
2380
2381
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2379

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datastore_mount_configGoogle::Apis::VmwareengineV1::DatastoreMountConfig

The Datastore Mount configuration Corresponds to the JSON property datastoreMountConfig



2354
2355
2356
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2354

def datastore_mount_config
  @datastore_mount_config
end

#ignore_colocationBoolean Also known as: ignore_colocation?

Optional. If set to true, the colocation requirement will be ignored. If set to false, the colocation requirement will be enforced. If not set, the colocation requirement will be enforced. Colocation requirement is the requirement that the cluster must be in the same region/zone of datastore( regional/zonal datastore). Corresponds to the JSON property ignoreColocation

Returns:

  • (Boolean)


2363
2364
2365
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2363

def ignore_colocation
  @ignore_colocation
end

#request_idString

Optional. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


2370
2371
2372
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2370

def request_id
  @request_id
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set to true, only validates the request but doesn’t execute the request. If set to false, validates and executes the request. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


2376
2377
2378
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2376

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2384
2385
2386
2387
2388
2389
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2384

def update!(**args)
  @datastore_mount_config = args[:datastore_mount_config] if args.key?(:datastore_mount_config)
  @ignore_colocation = args[:ignore_colocation] if args.key?(:ignore_colocation)
  @request_id = args[:request_id] if args.key?(:request_id)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end