Class: Google::Apis::VmwareengineV1::NetworkService

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Represents a network service that is managed by a NetworkPolicy resource. A network service provides a way to control an aspect of external access to VMware workloads. For example, whether the VMware workloads in the private clouds governed by a network policy can access or be accessed from the internet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkService

Returns a new instance of NetworkService.



2708
2709
2710
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2708

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

True if the service is enabled; false otherwise. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


2699
2700
2701
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2699

def enabled
  @enabled
end

#stateString

Output only. State of the service. New values may be added to this enum when appropriate. Corresponds to the JSON property state

Returns:

  • (String)


2706
2707
2708
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2706

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2713
2714
2715
2716
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2713

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @state = args[:state] if args.key?(:state)
end