Class: Google::Apis::VmwareengineV1::NodeType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Describes node type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeType

Returns a new instance of NodeType.



2876
2877
2878
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2876

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_custom_core_countsArray<Fixnum>

Output only. List of possible values of custom core count. Corresponds to the JSON property availableCustomCoreCounts

Returns:

  • (Array<Fixnum>)


2818
2819
2820
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2818

def available_custom_core_counts
  @available_custom_core_counts
end

#capabilitiesArray<String>

Output only. Capabilities of this node type. Corresponds to the JSON property capabilities

Returns:

  • (Array<String>)


2823
2824
2825
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2823

def capabilities
  @capabilities
end

#disk_size_gbFixnum

Output only. The amount of storage available, defined in GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


2828
2829
2830
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2828

def disk_size_gb
  @disk_size_gb
end

#display_nameString

Output only. The friendly name for this node type. For example: ve1-standard- 72 Corresponds to the JSON property displayName

Returns:

  • (String)


2834
2835
2836
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2834

def display_name
  @display_name
end

#familiesArray<String>

Output only. Families of the node type. For node types to be in the same cluster they must share at least one element in the families. Corresponds to the JSON property families

Returns:

  • (Array<String>)


2840
2841
2842
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2840

def families
  @families
end

#kindString

Output only. The type of the resource. Corresponds to the JSON property kind

Returns:

  • (String)


2845
2846
2847
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2845

def kind
  @kind
end

#memory_gbFixnum

Output only. The amount of physical memory available, defined in GB. Corresponds to the JSON property memoryGb

Returns:

  • (Fixnum)


2850
2851
2852
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2850

def memory_gb
  @memory_gb
end

#nameString

Output only. The resource name of this node type. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/ design/resource_names. For example: projects/my-proj/locations/us-central1-a/ nodeTypes/standard-72 Corresponds to the JSON property name

Returns:

  • (String)


2858
2859
2860
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2858

def name
  @name
end

#node_type_idString

Output only. The canonical identifier of the node type (corresponds to the NodeType). For example: standard-72. Corresponds to the JSON property nodeTypeId

Returns:

  • (String)


2864
2865
2866
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2864

def node_type_id
  @node_type_id
end

#total_core_countFixnum

Output only. The total number of CPU cores in a single node. Corresponds to the JSON property totalCoreCount

Returns:

  • (Fixnum)


2869
2870
2871
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2869

def total_core_count
  @total_core_count
end

#virtual_cpu_countFixnum

Output only. The total number of virtual CPUs in a single node. Corresponds to the JSON property virtualCpuCount

Returns:

  • (Fixnum)


2874
2875
2876
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2874

def virtual_cpu_count
  @virtual_cpu_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2881

def update!(**args)
  @available_custom_core_counts = args[:available_custom_core_counts] if args.key?(:available_custom_core_counts)
  @capabilities = args[:capabilities] if args.key?(:capabilities)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @display_name = args[:display_name] if args.key?(:display_name)
  @families = args[:families] if args.key?(:families)
  @kind = args[:kind] if args.key?(:kind)
  @memory_gb = args[:memory_gb] if args.key?(:memory_gb)
  @name = args[:name] if args.key?(:name)
  @node_type_id = args[:node_type_id] if args.key?(:node_type_id)
  @total_core_count = args[:total_core_count] if args.key?(:total_core_count)
  @virtual_cpu_count = args[:virtual_cpu_count] if args.key?(:virtual_cpu_count)
end