Class: Google::Apis::VmwareengineV1::NodeTypeConfig
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::NodeTypeConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Information about the type and number of nodes associated with the cluster.
Instance Attribute Summary collapse
-
#custom_core_count ⇒ Fixnum
Optional.
-
#node_count ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTypeConfig
constructor
A new instance of NodeTypeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTypeConfig
Returns a new instance of NodeTypeConfig.
2912 2913 2914 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_core_count ⇒ Fixnum
Optional. Customized number of cores available to each node of the type. This
number must always be one of nodeType.availableCustomCoreCounts. If zero is
provided max value from nodeType.availableCustomCoreCounts will be used.
Corresponds to the JSON property customCoreCount
2905 2906 2907 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2905 def custom_core_count @custom_core_count end |
#node_count ⇒ Fixnum
Required. The number of nodes of this type in the cluster
Corresponds to the JSON property nodeCount
2910 2911 2912 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2910 def node_count @node_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2917 2918 2919 2920 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2917 def update!(**args) @custom_core_count = args[:custom_core_count] if args.key?(:custom_core_count) @node_count = args[:node_count] if args.key?(:node_count) end |