Class: Google::Apis::VmwareengineV1::Principal
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::Principal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Users/Service accounts which have access for DNS binding on the intranet VPC corresponding to the consumer project.
Instance Attribute Summary collapse
-
#service_account ⇒ String
The service account which needs to be granted the permission.
-
#user ⇒ String
The user who needs to be granted permission.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Principal
constructor
A new instance of Principal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Principal
Returns a new instance of Principal.
3171 3172 3173 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3171 def initialize(**args) update!(**args) end |
Instance Attribute Details
#service_account ⇒ String
The service account which needs to be granted the permission.
Corresponds to the JSON property serviceAccount
3164 3165 3166 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3164 def service_account @service_account end |
#user ⇒ String
The user who needs to be granted permission.
Corresponds to the JSON property user
3169 3170 3171 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3169 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3176 3177 3178 3179 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3176 def update!(**args) @service_account = args[:service_account] if args.key?(:service_account) @user = args[:user] if args.key?(:user) end |