Class: Google::Apis::VmwareengineV1::PrivateCloud

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Represents a private cloud resource. Private clouds of type STANDARD and TIME_LIMITED are zonal resources, STRETCHED private clouds are regional.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivateCloud

Returns a new instance of PrivateCloud.



3345
3346
3347
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Creation time of this resource. Corresponds to the JSON property createTime

Returns:

  • (String)


3268
3269
3270
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3268

def create_time
  @create_time
end

#delete_timeString

Output only. Time when the resource was scheduled for deletion. Corresponds to the JSON property deleteTime

Returns:

  • (String)


3273
3274
3275
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3273

def delete_time
  @delete_time
end

#descriptionString

User-provided description for this private cloud. Corresponds to the JSON property description

Returns:

  • (String)


3278
3279
3280
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3278

def description
  @description
end

#encryption_configGoogle::Apis::VmwareengineV1::EncryptionConfig

Encryption configuration for a private cloud. Corresponds to the JSON property encryptionConfig



3283
3284
3285
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3283

def encryption_config
  @encryption_config
end

#expire_timeString

Output only. Time when the resource will be irreversibly deleted. Corresponds to the JSON property expireTime

Returns:

  • (String)


3288
3289
3290
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3288

def expire_time
  @expire_time
end

#hcxGoogle::Apis::VmwareengineV1::Hcx

Details about a HCX Cloud Manager appliance. Corresponds to the JSON property hcx



3293
3294
3295
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3293

def hcx
  @hcx
end

#management_clusterGoogle::Apis::VmwareengineV1::ManagementCluster

Management cluster configuration. Corresponds to the JSON property managementCluster



3298
3299
3300
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3298

def management_cluster
  @management_cluster
end

#nameString

Output only. Identifier. The resource name of this private cloud. Resource names are schemeless URIs that follow the conventions in https://cloud.google. com/apis/design/resource_names. For example: projects/my-project/locations/us- central1-a/privateClouds/my-cloud Corresponds to the JSON property name

Returns:

  • (String)


3306
3307
3308
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3306

def name
  @name
end

#network_configGoogle::Apis::VmwareengineV1::NetworkConfig

Network configuration in the consumer project with which the peering has to be done. Corresponds to the JSON property networkConfig



3312
3313
3314
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3312

def network_config
  @network_config
end

#nsxGoogle::Apis::VmwareengineV1::Nsx

Details about a NSX Manager appliance. Corresponds to the JSON property nsx



3317
3318
3319
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3317

def nsx
  @nsx
end

#stateString

Output only. State of the resource. New values may be added to this enum when appropriate. Corresponds to the JSON property state

Returns:

  • (String)


3323
3324
3325
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3323

def state
  @state
end

#typeString

Optional. Type of the private cloud. Defaults to STANDARD. Corresponds to the JSON property type

Returns:

  • (String)


3328
3329
3330
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3328

def type
  @type
end

#uidString

Output only. System-generated unique identifier for the resource. Corresponds to the JSON property uid

Returns:

  • (String)


3333
3334
3335
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3333

def uid
  @uid
end

#update_timeString

Output only. Last update time of this resource. Corresponds to the JSON property updateTime

Returns:

  • (String)


3338
3339
3340
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3338

def update_time
  @update_time
end

#vcenterGoogle::Apis::VmwareengineV1::Vcenter

Details about a vCenter Server management appliance. Corresponds to the JSON property vcenter



3343
3344
3345
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3343

def vcenter
  @vcenter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
3365
3366
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3350

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @description = args[:description] if args.key?(:description)
  @encryption_config = args[:encryption_config] if args.key?(:encryption_config)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @hcx = args[:hcx] if args.key?(:hcx)
  @management_cluster = args[:management_cluster] if args.key?(:management_cluster)
  @name = args[:name] if args.key?(:name)
  @network_config = args[:network_config] if args.key?(:network_config)
  @nsx = args[:nsx] if args.key?(:nsx)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vcenter = args[:vcenter] if args.key?(:vcenter)
end