Class: Google::Apis::VmwareengineV1::UnmountDatastoreRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Unmount Datastore Request messag

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnmountDatastoreRequest

Returns a new instance of UnmountDatastoreRequest.



4031
4032
4033
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4031

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datastoreString

Required. The resource name of the datastore to unmount. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/ design/resource_names. For example: projects/my-project/locations/us-central1/ datastores/my-datastore Corresponds to the JSON property datastore

Returns:

  • (String)


4016
4017
4018
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4016

def datastore
  @datastore
end

#request_idString

Optional. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


4022
4023
4024
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4022

def request_id
  @request_id
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set to true, only validates the request but doesn’t execute the request. If set to false, validates and executes the request. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


4028
4029
4030
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4028

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4036
4037
4038
4039
4040
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4036

def update!(**args)
  @datastore = args[:datastore] if args.key?(:datastore)
  @request_id = args[:request_id] if args.key?(:request_id)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end