Class: Google::Apis::VmwareengineV1::VmwareEngineNetwork
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::VmwareEngineNetwork
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
VMware Engine network resource that provides connectivity for VMware Engine private clouds.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
User-provided description for this VMware Engine network.
-
#etag ⇒ String
Checksum that may be sent on update and delete requests to ensure that the user-provided value is up to date before the server processes a request.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Required.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#vpc_networks ⇒ Array<Google::Apis::VmwareengineV1::VpcNetwork>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmwareEngineNetwork
constructor
A new instance of VmwareEngineNetwork.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmwareEngineNetwork
Returns a new instance of VmwareEngineNetwork.
4250 4251 4252 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4250 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Creation time of this resource.
Corresponds to the JSON property createTime
4201 4202 4203 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4201 def create_time @create_time end |
#description ⇒ String
User-provided description for this VMware Engine network.
Corresponds to the JSON property description
4206 4207 4208 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4206 def description @description end |
#etag ⇒ String
Checksum that may be sent on update and delete requests to ensure that the
user-provided value is up to date before the server processes a request. The
server computes checksums based on the value of other fields in the request.
Corresponds to the JSON property etag
4213 4214 4215 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4213 def etag @etag end |
#name ⇒ String
Output only. Identifier. The resource name of the VMware Engine network.
Resource names are schemeless URIs that follow the conventions in https://
cloud.google.com/apis/design/resource_names. For example: projects/my-project/
locations/global/vmwareEngineNetworks/my-network
Corresponds to the JSON property name
4221 4222 4223 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4221 def name @name end |
#state ⇒ String
Output only. State of the VMware Engine network.
Corresponds to the JSON property state
4226 4227 4228 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4226 def state @state end |
#type ⇒ String
Required. VMware Engine network type.
Corresponds to the JSON property type
4231 4232 4233 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4231 def type @type end |
#uid ⇒ String
Output only. System-generated unique identifier for the resource.
Corresponds to the JSON property uid
4236 4237 4238 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4236 def uid @uid end |
#update_time ⇒ String
Output only. Last update time of this resource.
Corresponds to the JSON property updateTime
4241 4242 4243 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4241 def update_time @update_time end |
#vpc_networks ⇒ Array<Google::Apis::VmwareengineV1::VpcNetwork>
Output only. VMware Engine service VPC networks that provide connectivity from
a private cloud to customer projects, the internet, and other Google Cloud
services.
Corresponds to the JSON property vpcNetworks
4248 4249 4250 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4248 def vpc_networks @vpc_networks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4255 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @vpc_networks = args[:vpc_networks] if args.key?(:vpc_networks) end |