Class: Google::Apis::VmwareengineV1::WeeklyTimeInterval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Represents a time interval, spanning across days of the week. Until local timezones are supported, this interval is in UTC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WeeklyTimeInterval

Returns a new instance of WeeklyTimeInterval.



4386
4387
4388
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4386

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_dayString

Output only. The day on which the interval ends. Can be same as start day. Corresponds to the JSON property endDay

Returns:

  • (String)


4365
4366
4367
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4365

def end_day
  @end_day
end

#end_timeGoogle::Apis::VmwareengineV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property endTime



4372
4373
4374
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4372

def end_time
  @end_time
end

#start_dayString

Output only. The day on which the interval starts. Corresponds to the JSON property startDay

Returns:

  • (String)


4377
4378
4379
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4377

def start_day
  @start_day
end

#start_timeGoogle::Apis::VmwareengineV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



4384
4385
4386
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4384

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4391
4392
4393
4394
4395
4396
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4391

def update!(**args)
  @end_day = args[:end_day] if args.key?(:end_day)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_day = args[:start_day] if args.key?(:start_day)
  @start_time = args[:start_time] if args.key?(:start_time)
end