Class: Google::Apis::VmwareengineV1::Announcement
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::Announcement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Announcement for the resources of Vmware Engine.
Instance Attribute Summary collapse
-
#activity_type ⇒ String
Optional.
-
#cluster ⇒ String
A Cluster resource name.
-
#code ⇒ String
Required.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#metadata ⇒ Hash<String,String>
Output only.
-
#name ⇒ String
Output only.
-
#private_cloud ⇒ String
A Private Cloud resource name.
-
#state ⇒ String
Output only.
-
#target_resource_type ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Announcement
constructor
A new instance of Announcement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Announcement
Returns a new instance of Announcement.
122 123 124 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 122 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activity_type ⇒ String
Optional. Activity type of the announcement There can be only one active
announcement for a given activity type and target resource.
Corresponds to the JSON property activityType
62 63 64 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 62 def activity_type @activity_type end |
#cluster ⇒ String
A Cluster resource name.
Corresponds to the JSON property cluster
67 68 69 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 67 def cluster @cluster end |
#code ⇒ String
Required. Code of the announcement. Indicates the presence of a VMware Engine
related announcement and corresponds to a related message in the description
field.
Corresponds to the JSON property code
74 75 76 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 74 def code @code end |
#create_time ⇒ String
Output only. Creation time of this resource. It also serves as start time of
notification.
Corresponds to the JSON property createTime
80 81 82 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 80 def create_time @create_time end |
#description ⇒ String
Output only. Description of the announcement.
Corresponds to the JSON property description
85 86 87 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 85 def description @description end |
#metadata ⇒ Hash<String,String>
Output only. Additional structured details about this announcement.
Corresponds to the JSON property metadata
90 91 92 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 90 def @metadata end |
#name ⇒ String
Output only. The resource name of the announcement. Resource names are
schemeless URIs that follow the conventions in https://cloud.google.com/apis/
design/resource_names. For example: projects/my-project/locations/us-west1-a/
announcements/my-announcement-id
Corresponds to the JSON property name
98 99 100 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 98 def name @name end |
#private_cloud ⇒ String
A Private Cloud resource name.
Corresponds to the JSON property privateCloud
103 104 105 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 103 def private_cloud @private_cloud end |
#state ⇒ String
Output only. State of the resource. New values may be added to this enum when
appropriate.
Corresponds to the JSON property state
109 110 111 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 109 def state @state end |
#target_resource_type ⇒ String
Output only. Target Resource Type defines the type of the target for the
announcement
Corresponds to the JSON property targetResourceType
115 116 117 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 115 def target_resource_type @target_resource_type end |
#update_time ⇒ String
Output only. Last update time of this resource.
Corresponds to the JSON property updateTime
120 121 122 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 120 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 127 def update!(**args) @activity_type = args[:activity_type] if args.key?(:activity_type) @cluster = args[:cluster] if args.key?(:cluster) @code = args[:code] if args.key?(:code) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @private_cloud = args[:private_cloud] if args.key?(:private_cloud) @state = args[:state] if args.key?(:state) @target_resource_type = args[:target_resource_type] if args.key?(:target_resource_type) @update_time = args[:update_time] if args.key?(:update_time) end |