Class: Google::Apis::VmwareengineV1::AutoscalingSettings
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::AutoscalingSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Autoscaling settings define the rules used by VMware Engine to automatically scale-out and scale-in the clusters in a private cloud.
Instance Attribute Summary collapse
-
#autoscaling_policies ⇒ Hash<String,Google::Apis::VmwareengineV1::AutoscalingPolicy>
Required.
-
#cool_down_period ⇒ String
Optional.
-
#max_cluster_node_count ⇒ Fixnum
Optional.
-
#min_cluster_node_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalingSettings
constructor
A new instance of AutoscalingSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalingSettings
Returns a new instance of AutoscalingSettings.
308 309 310 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 308 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_policies ⇒ Hash<String,Google::Apis::VmwareengineV1::AutoscalingPolicy>
Required. The map with autoscaling policies applied to the cluster. The key is
the identifier of the policy. It must meet the following requirements: * Only
contains 1-63 alphanumeric characters and hyphens * Begins with an
alphabetical character * Ends with a non-hyphen character * Not formatted as a
UUID * Complies with RFC 1034
(section 3.5) Currently there map must contain only one element that describes
the autoscaling policy for compute nodes.
Corresponds to the JSON property autoscalingPolicies
286 287 288 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 286 def autoscaling_policies @autoscaling_policies end |
#cool_down_period ⇒ String
Optional. The minimum duration between consecutive autoscale operations. It
starts once addition or removal of nodes is fully completed. Defaults to 30
minutes if not specified. Cool down period must be in whole minutes (for
example, 30, 31, 50, 180 minutes).
Corresponds to the JSON property coolDownPeriod
294 295 296 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 294 def cool_down_period @cool_down_period end |
#max_cluster_node_count ⇒ Fixnum
Optional. Maximum number of nodes of any type in a cluster. If not specified
the default limits apply.
Corresponds to the JSON property maxClusterNodeCount
300 301 302 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 300 def max_cluster_node_count @max_cluster_node_count end |
#min_cluster_node_count ⇒ Fixnum
Optional. Minimum number of nodes of any type in a cluster. If not specified
the default limits apply.
Corresponds to the JSON property minClusterNodeCount
306 307 308 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 306 def min_cluster_node_count @min_cluster_node_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
313 314 315 316 317 318 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 313 def update!(**args) @autoscaling_policies = args[:autoscaling_policies] if args.key?(:autoscaling_policies) @cool_down_period = args[:cool_down_period] if args.key?(:cool_down_period) @max_cluster_node_count = args[:max_cluster_node_count] if args.key?(:max_cluster_node_count) @min_cluster_node_count = args[:min_cluster_node_count] if args.key?(:min_cluster_node_count) end |