Class: Google::Apis::VmwareengineV1::Cluster
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::Cluster
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
A cluster in a private cloud.
Instance Attribute Summary collapse
-
#autoscaling_settings ⇒ Google::Apis::VmwareengineV1::AutoscalingSettings
Autoscaling settings define the rules used by VMware Engine to automatically scale-out and scale-in the clusters in a private cloud.
-
#create_time ⇒ String
Output only.
-
#datastore_mount_config ⇒ Array<Google::Apis::VmwareengineV1::DatastoreMountConfig>
Output only.
-
#management ⇒ Boolean
(also: #management?)
Output only.
-
#name ⇒ String
Output only.
-
#node_type_configs ⇒ Hash<String,Google::Apis::VmwareengineV1::NodeTypeConfig>
Required.
-
#state ⇒ String
Output only.
-
#stretched_cluster_config ⇒ Google::Apis::VmwareengineV1::StretchedClusterConfig
Configuration of a stretched cluster.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Cluster
constructor
A new instance of Cluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Cluster
Returns a new instance of Cluster.
484 485 486 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 484 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_settings ⇒ Google::Apis::VmwareengineV1::AutoscalingSettings
Autoscaling settings define the rules used by VMware Engine to automatically
scale-out and scale-in the clusters in a private cloud.
Corresponds to the JSON property autoscalingSettings
430 431 432 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 430 def autoscaling_settings @autoscaling_settings end |
#create_time ⇒ String
Output only. Creation time of this resource.
Corresponds to the JSON property createTime
435 436 437 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 435 def create_time @create_time end |
#datastore_mount_config ⇒ Array<Google::Apis::VmwareengineV1::DatastoreMountConfig>
Output only. Configuration of a mounted datastore.
Corresponds to the JSON property datastoreMountConfig
440 441 442 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 440 def datastore_mount_config @datastore_mount_config end |
#management ⇒ Boolean Also known as: management?
Output only. True if the cluster is a management cluster; false otherwise.
There can only be one management cluster in a private cloud and it has to be
the first one.
Corresponds to the JSON property management
447 448 449 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 447 def management @management end |
#name ⇒ String
Output only. Identifier. The resource name of this cluster. Resource names are
schemeless URIs that follow the conventions in https://cloud.google.com/apis/
design/resource_names. For example: projects/my-project/locations/us-central1-
a/privateClouds/my-cloud/clusters/my-cluster
Corresponds to the JSON property name
456 457 458 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 456 def name @name end |
#node_type_configs ⇒ Hash<String,Google::Apis::VmwareengineV1::NodeTypeConfig>
Required. The map of cluster node types in this cluster, where the key is
canonical identifier of the node type (corresponds to the NodeType).
Corresponds to the JSON property nodeTypeConfigs
462 463 464 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 462 def node_type_configs @node_type_configs end |
#state ⇒ String
Output only. State of the resource.
Corresponds to the JSON property state
467 468 469 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 467 def state @state end |
#stretched_cluster_config ⇒ Google::Apis::VmwareengineV1::StretchedClusterConfig
Configuration of a stretched cluster.
Corresponds to the JSON property stretchedClusterConfig
472 473 474 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 472 def stretched_cluster_config @stretched_cluster_config end |
#uid ⇒ String
Output only. System-generated unique identifier for the resource.
Corresponds to the JSON property uid
477 478 479 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 477 def uid @uid end |
#update_time ⇒ String
Output only. Last update time of this resource.
Corresponds to the JSON property updateTime
482 483 484 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 482 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
489 490 491 492 493 494 495 496 497 498 499 500 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 489 def update!(**args) @autoscaling_settings = args[:autoscaling_settings] if args.key?(:autoscaling_settings) @create_time = args[:create_time] if args.key?(:create_time) @datastore_mount_config = args[:datastore_mount_config] if args.key?(:datastore_mount_config) @management = args[:management] if args.key?(:management) @name = args[:name] if args.key?(:name) @node_type_configs = args[:node_type_configs] if args.key?(:node_type_configs) @state = args[:state] if args.key?(:state) @stretched_cluster_config = args[:stretched_cluster_config] if args.key?(:stretched_cluster_config) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |