Class: Google::Apis::VmwareengineV1::Datastore
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::Datastore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Represents a datastore resource.
Instance Attribute Summary collapse
-
#clusters ⇒ Array<String>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#name ⇒ String
Output only.
-
#nfs_datastore ⇒ Google::Apis::VmwareengineV1::NfsDatastore
The NFS datastore configuration.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Datastore
constructor
A new instance of Datastore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Datastore
Returns a new instance of Datastore.
630 631 632 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 630 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clusters ⇒ Array<String>
Output only. Clusters to which the datastore is attached.
Corresponds to the JSON property clusters
582 583 584 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 582 def clusters @clusters end |
#create_time ⇒ String
Output only. Creation time of this resource.
Corresponds to the JSON property createTime
587 588 589 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 587 def create_time @create_time end |
#description ⇒ String
Optional. User-provided description for this datastore
Corresponds to the JSON property description
592 593 594 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 592 def description @description end |
#etag ⇒ String
Optional. Checksum that may be sent on update and delete requests to ensure
that the user-provided value is up to date before the server processes a
request. The server computes checksums based on the value of other fields in
the request.
Corresponds to the JSON property etag
600 601 602 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 600 def etag @etag end |
#name ⇒ String
Output only. Identifier. The resource name of this datastore. Resource names
are schemeless URIs that follow the conventions in https://cloud.google.com/
apis/design/resource_names. For example: projects/my-project/locations/us-
central1/datastores/datastore
Corresponds to the JSON property name
608 609 610 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 608 def name @name end |
#nfs_datastore ⇒ Google::Apis::VmwareengineV1::NfsDatastore
The NFS datastore configuration.
Corresponds to the JSON property nfsDatastore
613 614 615 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 613 def nfs_datastore @nfs_datastore end |
#state ⇒ String
Output only. The state of the Datastore.
Corresponds to the JSON property state
618 619 620 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 618 def state @state end |
#uid ⇒ String
Output only. System-generated unique identifier for the resource.
Corresponds to the JSON property uid
623 624 625 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 623 def uid @uid end |
#update_time ⇒ String
Output only. Last update time of this resource.
Corresponds to the JSON property updateTime
628 629 630 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 628 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
635 636 637 638 639 640 641 642 643 644 645 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 635 def update!(**args) @clusters = args[:clusters] if args.key?(:clusters) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @nfs_datastore = args[:nfs_datastore] if args.key?(:nfs_datastore) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |