Class: Google::Apis::VmwareengineV1::GrantDnsBindPermissionRequest
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::GrantDnsBindPermissionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Request message for VmwareEngine.GrantDnsBindPermission
Instance Attribute Summary collapse
-
#principal ⇒ Google::Apis::VmwareengineV1::Principal
Users/Service accounts which have access for DNS binding on the intranet VPC corresponding to the consumer project.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrantDnsBindPermissionRequest
constructor
A new instance of GrantDnsBindPermissionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrantDnsBindPermissionRequest
Returns a new instance of GrantDnsBindPermissionRequest.
1203 1204 1205 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1203 def initialize(**args) update!(**args) end |
Instance Attribute Details
#principal ⇒ Google::Apis::VmwareengineV1::Principal
Users/Service accounts which have access for DNS binding on the intranet VPC
corresponding to the consumer project.
Corresponds to the JSON property principal
1186 1187 1188 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1186 def principal @principal end |
#request_id ⇒ String
Optional. A request ID to identify requests. Specify a unique request ID so
that if you must retry your request, the server will know to ignore the
request if it has already been completed. The server guarantees that a request
doesn't result in creation of duplicate commitments for at least 60 minutes.
For example, consider a situation where you make an initial request and the
request times out. If you make the request again with the same request ID, the
server can check if original operation with the same request ID was received,
and if so, will ignore the second request. This prevents clients from
accidentally creating duplicate commitments. The request ID must be a valid
UUID with the exception that zero UUID is not supported (00000000-0000-0000-
0000-000000000000).
Corresponds to the JSON property requestId
1201 1202 1203 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1201 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1208 1209 1210 1211 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1208 def update!(**args) @principal = args[:principal] if args.key?(:principal) @request_id = args[:request_id] if args.key?(:request_id) end |