Class: Google::Apis::VmwareengineV1::HcxActivationKey
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::HcxActivationKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
HCX activation key. A default key is created during private cloud provisioning, but this behavior is subject to change and you should always verify active keys. Use VmwareEngine.ListHcxActivationKeys to retrieve existing keys and VmwareEngine.CreateHcxActivationKey to create new ones.
Instance Attribute Summary collapse
-
#activation_key ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HcxActivationKey
constructor
A new instance of HcxActivationKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HcxActivationKey
Returns a new instance of HcxActivationKey.
1316 1317 1318 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1316 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_key ⇒ String
Output only. HCX activation key.
Corresponds to the JSON property activationKey
1291 1292 1293 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1291 def activation_key @activation_key end |
#create_time ⇒ String
Output only. Creation time of HCX activation key.
Corresponds to the JSON property createTime
1296 1297 1298 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1296 def create_time @create_time end |
#name ⇒ String
Output only. The resource name of this HcxActivationKey. Resource names are
schemeless URIs that follow the conventions in https://cloud.google.com/apis/
design/resource_names. For example: projects/my-project/locations/us-central1/
privateClouds/my-cloud/hcxActivationKeys/my-key
Corresponds to the JSON property name
1304 1305 1306 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1304 def name @name end |
#state ⇒ String
Output only. State of HCX activation key.
Corresponds to the JSON property state
1309 1310 1311 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1309 def state @state end |
#uid ⇒ String
Output only. System-generated unique identifier for the resource.
Corresponds to the JSON property uid
1314 1315 1316 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1314 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1321 1322 1323 1324 1325 1326 1327 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1321 def update!(**args) @activation_key = args[:activation_key] if args.key?(:activation_key) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) end |