Class: Google::Apis::VmwareengineV1::HcxActivationKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

HCX activation key. A default key is created during private cloud provisioning, but this behavior is subject to change and you should always verify active keys. Use VmwareEngine.ListHcxActivationKeys to retrieve existing keys and VmwareEngine.CreateHcxActivationKey to create new ones.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HcxActivationKey

Returns a new instance of HcxActivationKey.



1286
1287
1288
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activation_keyString

Output only. HCX activation key. Corresponds to the JSON property activationKey

Returns:

  • (String)


1261
1262
1263
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1261

def activation_key
  @activation_key
end

#create_timeString

Output only. Creation time of HCX activation key. Corresponds to the JSON property createTime

Returns:

  • (String)


1266
1267
1268
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1266

def create_time
  @create_time
end

#nameString

Output only. The resource name of this HcxActivationKey. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/ design/resource_names. For example: projects/my-project/locations/us-central1/ privateClouds/my-cloud/hcxActivationKeys/my-key Corresponds to the JSON property name

Returns:

  • (String)


1274
1275
1276
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1274

def name
  @name
end

#stateString

Output only. State of HCX activation key. Corresponds to the JSON property state

Returns:

  • (String)


1279
1280
1281
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1279

def state
  @state
end

#uidString

Output only. System-generated unique identifier for the resource. Corresponds to the JSON property uid

Returns:

  • (String)


1284
1285
1286
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1284

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1291
1292
1293
1294
1295
1296
1297
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1291

def update!(**args)
  @activation_key = args[:activation_key] if args.key?(:activation_key)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
end