Class: Google::Apis::VmwareengineV1::IpRange
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::IpRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
An IP range provided in any one of the supported formats.
Instance Attribute Summary collapse
-
#external_address ⇒ String
The name of an
ExternalAddressresource. -
#ip_address ⇒ String
A single IP address.
-
#ip_address_range ⇒ String
An IP address range in the CIDR format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IpRange
constructor
A new instance of IpRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IpRange
Returns a new instance of IpRange.
1354 1355 1356 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1354 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_address ⇒ String
The name of an ExternalAddress resource. The external address must have been
reserved in the scope of this external access rule's parent network policy.
Provide the external address name in the form of projects/project/locations/
location/privateClouds/private_cloud/externalAddresses/external_address`.
For example:projects/my-project/locations/us-central1-a/privateClouds/my-
cloud/externalAddresses/my-address.
Corresponds to the JSON propertyexternalAddress`
1342 1343 1344 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1342 def external_address @external_address end |
#ip_address ⇒ String
A single IP address. For example: 10.0.0.5.
Corresponds to the JSON property ipAddress
1347 1348 1349 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1347 def ip_address @ip_address end |
#ip_address_range ⇒ String
An IP address range in the CIDR format. For example: 10.0.0.0/24.
Corresponds to the JSON property ipAddressRange
1352 1353 1354 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1352 def ip_address_range @ip_address_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1359 1360 1361 1362 1363 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1359 def update!(**args) @external_address = args[:external_address] if args.key?(:external_address) @ip_address = args[:ip_address] if args.key?(:ip_address) @ip_address_range = args[:ip_address_range] if args.key?(:ip_address_range) end |