Class: Google::Apis::VmwareengineV1::ListClustersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Response message for VmwareEngine.ListClusters

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListClustersResponse

Returns a new instance of ListClustersResponse.



1419
1420
1421
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clustersArray<Google::Apis::VmwareengineV1::Cluster>

A list of private cloud clusters. Corresponds to the JSON property clusters



1405
1406
1407
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1405

def clusters
  @clusters
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1411
1412
1413
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1411

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached when making an aggregated query using wildcards. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1417
1418
1419
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1417

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1424
1425
1426
1427
1428
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1424

def update!(**args)
  @clusters = args[:clusters] if args.key?(:clusters)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end