Class: Google::Apis::VmwareengineV1::ListLoggingServersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Response message for VmwareEngine.ListLoggingServers

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListLoggingServersResponse

Returns a new instance of ListLoggingServersResponse.



1608
1609
1610
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1608

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#logging_serversArray<Google::Apis::VmwareengineV1::LoggingServer>

A list of Logging Servers. Corresponds to the JSON property loggingServers



1594
1595
1596
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1594

def logging_servers
  @logging_servers
end

#next_page_tokenString

A token, which can be send as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1600
1601
1602
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1600

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached when making an aggregated query using wildcards. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1606
1607
1608
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1606

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1613
1614
1615
1616
1617
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1613

def update!(**args)
  @logging_servers = args[:logging_servers] if args.key?(:logging_servers)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end