Class: Google::Apis::VmwareengineV1::ListManagementDnsZoneBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::ListManagementDnsZoneBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Response message for VmwareEngine.ListManagementDnsZoneBindings
Instance Attribute Summary collapse
-
#management_dns_zone_bindings ⇒ Array<Google::Apis::VmwareengineV1::ManagementDnsZoneBinding>
A list of management DNS zone bindings.
-
#next_page_token ⇒ String
A token, which can be sent as
page_tokento retrieve the next page. -
#unreachable ⇒ Array<String>
Locations that could not be reached when making an aggregated query using wildcards.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListManagementDnsZoneBindingsResponse
constructor
A new instance of ListManagementDnsZoneBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListManagementDnsZoneBindingsResponse
Returns a new instance of ListManagementDnsZoneBindingsResponse.
1671 1672 1673 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1671 def initialize(**args) update!(**args) end |
Instance Attribute Details
#management_dns_zone_bindings ⇒ Array<Google::Apis::VmwareengineV1::ManagementDnsZoneBinding>
A list of management DNS zone bindings.
Corresponds to the JSON property managementDnsZoneBindings
1657 1658 1659 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1657 def management_dns_zone_bindings @management_dns_zone_bindings end |
#next_page_token ⇒ String
A token, which can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
1663 1664 1665 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1663 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached when making an aggregated query using
wildcards.
Corresponds to the JSON property unreachable
1669 1670 1671 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1669 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1676 1677 1678 1679 1680 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1676 def update!(**args) @management_dns_zone_bindings = args[:management_dns_zone_bindings] if args.key?(:management_dns_zone_bindings) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |