Class: Google::Apis::VmwareengineV1::ListPrivateCloudsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Response message for VmwareEngine.ListPrivateClouds

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPrivateCloudsResponse

Returns a new instance of ListPrivateCloudsResponse.



1858
1859
1860
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1858

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1845
1846
1847
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1845

def next_page_token
  @next_page_token
end

#private_cloudsArray<Google::Apis::VmwareengineV1::PrivateCloud>

A list of private clouds. Corresponds to the JSON property privateClouds



1850
1851
1852
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1850

def private_clouds
  @private_clouds
end

#unreachableArray<String>

Locations that could not be reached when making an aggregated query using wildcards. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1856
1857
1858
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1856

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1863
1864
1865
1866
1867
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 1863

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @private_clouds = args[:private_clouds] if args.key?(:private_clouds)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end