Class: Google::Apis::VmwareengineV1::MountDatastoreRequest
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::MountDatastoreRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Mount Datastore Request message
Instance Attribute Summary collapse
-
#datastore_mount_config ⇒ Google::Apis::VmwareengineV1::DatastoreMountConfig
The Datastore Mount configuration Corresponds to the JSON property
datastoreMountConfig. -
#ignore_colocation ⇒ Boolean
(also: #ignore_colocation?)
Optional.
-
#request_id ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MountDatastoreRequest
constructor
A new instance of MountDatastoreRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MountDatastoreRequest
Returns a new instance of MountDatastoreRequest.
2349 2350 2351 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2349 def initialize(**args) update!(**args) end |
Instance Attribute Details
#datastore_mount_config ⇒ Google::Apis::VmwareengineV1::DatastoreMountConfig
The Datastore Mount configuration
Corresponds to the JSON property datastoreMountConfig
2324 2325 2326 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2324 def datastore_mount_config @datastore_mount_config end |
#ignore_colocation ⇒ Boolean Also known as: ignore_colocation?
Optional. If set to true, the colocation requirement will be ignored. If set
to false, the colocation requirement will be enforced. If not set, the
colocation requirement will be enforced. Colocation requirement is the
requirement that the cluster must be in the same region/zone of datastore(
regional/zonal datastore).
Corresponds to the JSON property ignoreColocation
2333 2334 2335 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2333 def ignore_colocation @ignore_colocation end |
#request_id ⇒ String
Optional. The request ID must be a valid UUID with the exception that zero
UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
2340 2341 2342 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2340 def request_id @request_id end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set to true, only validates the request but doesn’t execute the
request. If set to false, validates and executes the request.
Corresponds to the JSON property validateOnly
2346 2347 2348 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2346 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2354 2355 2356 2357 2358 2359 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2354 def update!(**args) @datastore_mount_config = args[:datastore_mount_config] if args.key?(:datastore_mount_config) @ignore_colocation = args[:ignore_colocation] if args.key?(:ignore_colocation) @request_id = args[:request_id] if args.key?(:request_id) @validate_only = args[:validate_only] if args.key?(:validate_only) end |