Class: Google::Apis::VmwareengineV1::MountDatastoreRequest
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::MountDatastoreRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Mount Datastore Request message
Instance Attribute Summary collapse
-
#datastore_mount_config ⇒ Google::Apis::VmwareengineV1::DatastoreMountConfig
The Datastore Mount configuration Corresponds to the JSON property
datastoreMountConfig. -
#ignore_colocation ⇒ Boolean
(also: #ignore_colocation?)
Optional.
-
#request_id ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MountDatastoreRequest
constructor
A new instance of MountDatastoreRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MountDatastoreRequest
Returns a new instance of MountDatastoreRequest.
2301 2302 2303 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2301 def initialize(**args) update!(**args) end |
Instance Attribute Details
#datastore_mount_config ⇒ Google::Apis::VmwareengineV1::DatastoreMountConfig
The Datastore Mount configuration
Corresponds to the JSON property datastoreMountConfig
2276 2277 2278 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2276 def datastore_mount_config @datastore_mount_config end |
#ignore_colocation ⇒ Boolean Also known as: ignore_colocation?
Optional. If set to true, the colocation requirement will be ignored. If set
to false, the colocation requirement will be enforced. If not set, the
colocation requirement will be enforced. Colocation requirement is the
requirement that the cluster must be in the same region/zone of datastore(
regional/zonal datastore).
Corresponds to the JSON property ignoreColocation
2285 2286 2287 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2285 def ignore_colocation @ignore_colocation end |
#request_id ⇒ String
Optional. The request ID must be a valid UUID with the exception that zero
UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
2292 2293 2294 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2292 def request_id @request_id end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set to true, only validates the request but doesn’t execute the
request. If set to false, validates and executes the request.
Corresponds to the JSON property validateOnly
2298 2299 2300 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2298 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2306 2307 2308 2309 2310 2311 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2306 def update!(**args) @datastore_mount_config = args[:datastore_mount_config] if args.key?(:datastore_mount_config) @ignore_colocation = args[:ignore_colocation] if args.key?(:ignore_colocation) @request_id = args[:request_id] if args.key?(:request_id) @validate_only = args[:validate_only] if args.key?(:validate_only) end |