Class: Google::Apis::VmwareengineV1::NetworkPeering

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Details of a network peering.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPeering

Returns a new instance of NetworkPeering.



2489
2490
2491
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2489

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Creation time of this resource. Corresponds to the JSON property createTime

Returns:

  • (String)


2378
2379
2380
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2378

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description for this network peering. Corresponds to the JSON property description

Returns:

  • (String)


2383
2384
2385
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2383

def description
  @description
end

#exchange_subnet_routesBoolean Also known as: exchange_subnet_routes?

Optional. True if full mesh connectivity is created and managed automatically between peered networks; false otherwise. Currently this field is always true because Google Compute Engine automatically creates and manages subnetwork routes between two VPC networks when peering state is 'ACTIVE'. Corresponds to the JSON property exchangeSubnetRoutes

Returns:

  • (Boolean)


2391
2392
2393
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2391

def exchange_subnet_routes
  @exchange_subnet_routes
end

#export_custom_routesBoolean Also known as: export_custom_routes?

Optional. True if custom routes are exported to the peered network; false otherwise. The default value is true. Corresponds to the JSON property exportCustomRoutes

Returns:

  • (Boolean)


2398
2399
2400
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2398

def export_custom_routes
  @export_custom_routes
end

#export_custom_routes_with_public_ipBoolean Also known as: export_custom_routes_with_public_ip?

Optional. True if all subnet routes with a public IP address range are exported; false otherwise. The default value is true. IPv4 special-use ranges ( https://en.wikipedia.org/wiki/IPv4#Special_addresses) are always exported to peers and are not controlled by this field. Corresponds to the JSON property exportCustomRoutesWithPublicIp

Returns:

  • (Boolean)


2407
2408
2409
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2407

def export_custom_routes_with_public_ip
  @export_custom_routes_with_public_ip
end

#import_custom_routesBoolean Also known as: import_custom_routes?

Optional. True if custom routes are imported from the peered network; false otherwise. The default value is true. Corresponds to the JSON property importCustomRoutes

Returns:

  • (Boolean)


2414
2415
2416
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2414

def import_custom_routes
  @import_custom_routes
end

#import_custom_routes_with_public_ipBoolean Also known as: import_custom_routes_with_public_ip?

Optional. True if all subnet routes with public IP address range are imported; false otherwise. The default value is true. IPv4 special-use ranges (https:// en.wikipedia.org/wiki/IPv4#Special_addresses) are always imported to peers and are not controlled by this field. Corresponds to the JSON property importCustomRoutesWithPublicIp

Returns:

  • (Boolean)


2423
2424
2425
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2423

def import_custom_routes_with_public_ip
  @import_custom_routes_with_public_ip
end

#nameString

Output only. Identifier. The resource name of the network peering. NetworkPeering is a global resource and location can only be global. Resource names are scheme-less URIs that follow the conventions in https://cloud.google. com/apis/design/resource_names. For example: projects/my-project/locations/ global/networkPeerings/my-peering Corresponds to the JSON property name

Returns:

  • (String)


2433
2434
2435
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2433

def name
  @name
end

#peer_mtuFixnum

Optional. Maximum transmission unit (MTU) in bytes. The default value is 1500 . If a value of 0 is provided for this field, VMware Engine uses the default value instead. Corresponds to the JSON property peerMtu

Returns:

  • (Fixnum)


2440
2441
2442
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2440

def peer_mtu
  @peer_mtu
end

#peer_networkString

Required. The relative resource name of the network to peer with a standard VMware Engine network. The provided network can be a consumer VPC network or another standard VMware Engine network. If the peer_network_type is VMWARE_ENGINE_NETWORK, specify the name in the form: projects/project/ locations/global/vmwareEngineNetworks/vmware_engine_network_id. Otherwise specify the name in the form: `projects/`project`/global/networks/`network_id , where project can either be a project number or a project ID. Corresponds to the JSON property peerNetwork

Returns:

  • (String)


2451
2452
2453
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2451

def peer_network
  @peer_network
end

#peer_network_typeString

Required. The type of the network to peer with the VMware Engine network. Corresponds to the JSON property peerNetworkType

Returns:

  • (String)


2456
2457
2458
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2456

def peer_network_type
  @peer_network_type
end

#stateString

Output only. State of the network peering. This field has a value of 'ACTIVE' when there's a matching configuration in the peer network. New values may be added to this enum when appropriate. Corresponds to the JSON property state

Returns:

  • (String)


2463
2464
2465
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2463

def state
  @state
end

#state_detailsString

Output only. Output Only. Details about the current state of the network peering. Corresponds to the JSON property stateDetails

Returns:

  • (String)


2469
2470
2471
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2469

def state_details
  @state_details
end

#uidString

Output only. System-generated unique identifier for the resource. Corresponds to the JSON property uid

Returns:

  • (String)


2474
2475
2476
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2474

def uid
  @uid
end

#update_timeString

Output only. Last update time of this resource. Corresponds to the JSON property updateTime

Returns:

  • (String)


2479
2480
2481
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2479

def update_time
  @update_time
end

#vmware_engine_networkString

Required. The relative resource name of the VMware Engine network. Specify the name in the following form: projects/project/locations/location/ vmwareEngineNetworks/vmware_engine_network_idwhereproject`can either be a project number or a project ID. Corresponds to the JSON propertyvmwareEngineNetwork`

Returns:

  • (String)


2487
2488
2489
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2487

def vmware_engine_network
  @vmware_engine_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2494

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @exchange_subnet_routes = args[:exchange_subnet_routes] if args.key?(:exchange_subnet_routes)
  @export_custom_routes = args[:export_custom_routes] if args.key?(:export_custom_routes)
  @export_custom_routes_with_public_ip = args[:export_custom_routes_with_public_ip] if args.key?(:export_custom_routes_with_public_ip)
  @import_custom_routes = args[:import_custom_routes] if args.key?(:import_custom_routes)
  @import_custom_routes_with_public_ip = args[:import_custom_routes_with_public_ip] if args.key?(:import_custom_routes_with_public_ip)
  @name = args[:name] if args.key?(:name)
  @peer_mtu = args[:peer_mtu] if args.key?(:peer_mtu)
  @peer_network = args[:peer_network] if args.key?(:peer_network)
  @peer_network_type = args[:peer_network_type] if args.key?(:peer_network_type)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vmware_engine_network = args[:vmware_engine_network] if args.key?(:vmware_engine_network)
end