Class: Google::Apis::VmwareengineV1::NetworkPolicy
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::NetworkPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Represents a network policy resource. Network policies are regional resources. You can use a network policy to enable or disable internet access and external IP access. Network policies are associated with a VMware Engine network, which might span across regions. For a given region, a network policy applies to all private clouds in the VMware Engine network associated with the policy.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#edge_services_cidr ⇒ String
Required.
-
#external_ip ⇒ Google::Apis::VmwareengineV1::NetworkService
Represents a network service that is managed by a
NetworkPolicyresource. -
#internet_access ⇒ Google::Apis::VmwareengineV1::NetworkService
Represents a network service that is managed by a
NetworkPolicyresource. -
#name ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#vmware_engine_network ⇒ String
Optional.
-
#vmware_engine_network_canonical ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicy
constructor
A new instance of NetworkPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicy
Returns a new instance of NetworkPolicy.
2669 2670 2671 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2669 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Creation time of this resource.
Corresponds to the JSON property createTime
2603 2604 2605 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2603 def create_time @create_time end |
#description ⇒ String
Optional. User-provided description for this network policy.
Corresponds to the JSON property description
2608 2609 2610 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2608 def description @description end |
#edge_services_cidr ⇒ String
Required. IP address range in CIDR notation used to create internet access and
external IP access. An RFC 1918 CIDR block, with a "/26" prefix, is required.
The range cannot overlap with any prefixes either in the consumer VPC network
or in use by the private clouds attached to that VPC network.
Corresponds to the JSON property edgeServicesCidr
2616 2617 2618 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2616 def edge_services_cidr @edge_services_cidr end |
#external_ip ⇒ Google::Apis::VmwareengineV1::NetworkService
Represents a network service that is managed by a NetworkPolicy resource. A
network service provides a way to control an aspect of external access to
VMware workloads. For example, whether the VMware workloads in the private
clouds governed by a network policy can access or be accessed from the
internet.
Corresponds to the JSON property externalIp
2625 2626 2627 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2625 def external_ip @external_ip end |
#internet_access ⇒ Google::Apis::VmwareengineV1::NetworkService
Represents a network service that is managed by a NetworkPolicy resource. A
network service provides a way to control an aspect of external access to
VMware workloads. For example, whether the VMware workloads in the private
clouds governed by a network policy can access or be accessed from the
internet.
Corresponds to the JSON property internetAccess
2634 2635 2636 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2634 def internet_access @internet_access end |
#name ⇒ String
Output only. Identifier. The resource name of this network policy. Resource
names are schemeless URIs that follow the conventions in https://cloud.google.
com/apis/design/resource_names. For example: projects/my-project/locations/us-
central1/networkPolicies/my-network-policy
Corresponds to the JSON property name
2642 2643 2644 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2642 def name @name end |
#uid ⇒ String
Output only. System-generated unique identifier for the resource.
Corresponds to the JSON property uid
2647 2648 2649 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2647 def uid @uid end |
#update_time ⇒ String
Output only. Last update time of this resource.
Corresponds to the JSON property updateTime
2652 2653 2654 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2652 def update_time @update_time end |
#vmware_engine_network ⇒ String
Optional. The relative resource name of the VMware Engine network. Specify the
name in the following form: projects/project/locations/location/
vmwareEngineNetworks/vmware_engine_network_idwhereproject`can either
be a project number or a project ID.
Corresponds to the JSON propertyvmwareEngineNetwork`
2660 2661 2662 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2660 def vmware_engine_network @vmware_engine_network end |
#vmware_engine_network_canonical ⇒ String
Output only. The canonical name of the VMware Engine network in the form:
projects/project_number/locations/location/vmwareEngineNetworks/
vmware_engine_network_id`
Corresponds to the JSON propertyvmwareEngineNetworkCanonical`
2667 2668 2669 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2667 def vmware_engine_network_canonical @vmware_engine_network_canonical end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2674 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @edge_services_cidr = args[:edge_services_cidr] if args.key?(:edge_services_cidr) @external_ip = args[:external_ip] if args.key?(:external_ip) @internet_access = args[:internet_access] if args.key?(:internet_access) @name = args[:name] if args.key?(:name) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @vmware_engine_network = args[:vmware_engine_network] if args.key?(:vmware_engine_network) @vmware_engine_network_canonical = args[:vmware_engine_network_canonical] if args.key?(:vmware_engine_network_canonical) end |