Class: Google::Apis::VmwareengineV1::NetworkPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Represents a network policy resource. Network policies are regional resources. You can use a network policy to enable or disable internet access and external IP access. Network policies are associated with a VMware Engine network, which might span across regions. For a given region, a network policy applies to all private clouds in the VMware Engine network associated with the policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicy

Returns a new instance of NetworkPolicy.



2639
2640
2641
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2639

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Creation time of this resource. Corresponds to the JSON property createTime

Returns:

  • (String)


2573
2574
2575
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2573

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description for this network policy. Corresponds to the JSON property description

Returns:

  • (String)


2578
2579
2580
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2578

def description
  @description
end

#edge_services_cidrString

Required. IP address range in CIDR notation used to create internet access and external IP access. An RFC 1918 CIDR block, with a "/26" prefix, is required. The range cannot overlap with any prefixes either in the consumer VPC network or in use by the private clouds attached to that VPC network. Corresponds to the JSON property edgeServicesCidr

Returns:

  • (String)


2586
2587
2588
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2586

def edge_services_cidr
  @edge_services_cidr
end

#external_ipGoogle::Apis::VmwareengineV1::NetworkService

Represents a network service that is managed by a NetworkPolicy resource. A network service provides a way to control an aspect of external access to VMware workloads. For example, whether the VMware workloads in the private clouds governed by a network policy can access or be accessed from the internet. Corresponds to the JSON property externalIp



2595
2596
2597
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2595

def external_ip
  @external_ip
end

#internet_accessGoogle::Apis::VmwareengineV1::NetworkService

Represents a network service that is managed by a NetworkPolicy resource. A network service provides a way to control an aspect of external access to VMware workloads. For example, whether the VMware workloads in the private clouds governed by a network policy can access or be accessed from the internet. Corresponds to the JSON property internetAccess



2604
2605
2606
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2604

def internet_access
  @internet_access
end

#nameString

Output only. Identifier. The resource name of this network policy. Resource names are schemeless URIs that follow the conventions in https://cloud.google. com/apis/design/resource_names. For example: projects/my-project/locations/us- central1/networkPolicies/my-network-policy Corresponds to the JSON property name

Returns:

  • (String)


2612
2613
2614
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2612

def name
  @name
end

#uidString

Output only. System-generated unique identifier for the resource. Corresponds to the JSON property uid

Returns:

  • (String)


2617
2618
2619
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2617

def uid
  @uid
end

#update_timeString

Output only. Last update time of this resource. Corresponds to the JSON property updateTime

Returns:

  • (String)


2622
2623
2624
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2622

def update_time
  @update_time
end

#vmware_engine_networkString

Optional. The relative resource name of the VMware Engine network. Specify the name in the following form: projects/project/locations/location/ vmwareEngineNetworks/vmware_engine_network_idwhereproject`can either be a project number or a project ID. Corresponds to the JSON propertyvmwareEngineNetwork`

Returns:

  • (String)


2630
2631
2632
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2630

def vmware_engine_network
  @vmware_engine_network
end

#vmware_engine_network_canonicalString

Output only. The canonical name of the VMware Engine network in the form: projects/project_number/locations/location/vmwareEngineNetworks/ vmware_engine_network_id` Corresponds to the JSON propertyvmwareEngineNetworkCanonical`

Returns:

  • (String)


2637
2638
2639
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2637

def vmware_engine_network_canonical
  @vmware_engine_network_canonical
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2644
2645
2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2644

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @edge_services_cidr = args[:edge_services_cidr] if args.key?(:edge_services_cidr)
  @external_ip = args[:external_ip] if args.key?(:external_ip)
  @internet_access = args[:internet_access] if args.key?(:internet_access)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vmware_engine_network = args[:vmware_engine_network] if args.key?(:vmware_engine_network)
  @vmware_engine_network_canonical = args[:vmware_engine_network_canonical] if args.key?(:vmware_engine_network_canonical)
end