Class: Google::Apis::VmwareengineV1::NetworkPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Represents a network policy resource. Network policies are regional resources. You can use a network policy to enable or disable internet access and external IP access. Network policies are associated with a VMware Engine network, which might span across regions. For a given region, a network policy applies to all private clouds in the VMware Engine network associated with the policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicy

Returns a new instance of NetworkPolicy.



2591
2592
2593
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2591

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Creation time of this resource. Corresponds to the JSON property createTime

Returns:

  • (String)


2525
2526
2527
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2525

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description for this network policy. Corresponds to the JSON property description

Returns:

  • (String)


2530
2531
2532
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2530

def description
  @description
end

#edge_services_cidrString

Required. IP address range in CIDR notation used to create internet access and external IP access. An RFC 1918 CIDR block, with a "/26" prefix, is required. The range cannot overlap with any prefixes either in the consumer VPC network or in use by the private clouds attached to that VPC network. Corresponds to the JSON property edgeServicesCidr

Returns:

  • (String)


2538
2539
2540
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2538

def edge_services_cidr
  @edge_services_cidr
end

#external_ipGoogle::Apis::VmwareengineV1::NetworkService

Represents a network service that is managed by a NetworkPolicy resource. A network service provides a way to control an aspect of external access to VMware workloads. For example, whether the VMware workloads in the private clouds governed by a network policy can access or be accessed from the internet. Corresponds to the JSON property externalIp



2547
2548
2549
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2547

def external_ip
  @external_ip
end

#internet_accessGoogle::Apis::VmwareengineV1::NetworkService

Represents a network service that is managed by a NetworkPolicy resource. A network service provides a way to control an aspect of external access to VMware workloads. For example, whether the VMware workloads in the private clouds governed by a network policy can access or be accessed from the internet. Corresponds to the JSON property internetAccess



2556
2557
2558
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2556

def internet_access
  @internet_access
end

#nameString

Output only. Identifier. The resource name of this network policy. Resource names are schemeless URIs that follow the conventions in https://cloud.google. com/apis/design/resource_names. For example: projects/my-project/locations/us- central1/networkPolicies/my-network-policy Corresponds to the JSON property name

Returns:

  • (String)


2564
2565
2566
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2564

def name
  @name
end

#uidString

Output only. System-generated unique identifier for the resource. Corresponds to the JSON property uid

Returns:

  • (String)


2569
2570
2571
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2569

def uid
  @uid
end

#update_timeString

Output only. Last update time of this resource. Corresponds to the JSON property updateTime

Returns:

  • (String)


2574
2575
2576
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2574

def update_time
  @update_time
end

#vmware_engine_networkString

Optional. The relative resource name of the VMware Engine network. Specify the name in the following form: projects/project/locations/location/ vmwareEngineNetworks/vmware_engine_network_idwhereproject`can either be a project number or a project ID. Corresponds to the JSON propertyvmwareEngineNetwork`

Returns:

  • (String)


2582
2583
2584
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2582

def vmware_engine_network
  @vmware_engine_network
end

#vmware_engine_network_canonicalString

Output only. The canonical name of the VMware Engine network in the form: projects/project_number/locations/location/vmwareEngineNetworks/ vmware_engine_network_id` Corresponds to the JSON propertyvmwareEngineNetworkCanonical`

Returns:

  • (String)


2589
2590
2591
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2589

def vmware_engine_network_canonical
  @vmware_engine_network_canonical
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2596
2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2596

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @edge_services_cidr = args[:edge_services_cidr] if args.key?(:edge_services_cidr)
  @external_ip = args[:external_ip] if args.key?(:external_ip)
  @internet_access = args[:internet_access] if args.key?(:internet_access)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vmware_engine_network = args[:vmware_engine_network] if args.key?(:vmware_engine_network)
  @vmware_engine_network_canonical = args[:vmware_engine_network_canonical] if args.key?(:vmware_engine_network_canonical)
end