Class: Google::Apis::VmwareengineV1::NfsDatastore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

The NFS datastore configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NfsDatastore

Returns a new instance of NfsDatastore.



2661
2662
2663
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2661

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_file_serviceGoogle::Apis::VmwareengineV1::GoogleFileService

Google service file service configuration Corresponds to the JSON property googleFileService



2648
2649
2650
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2648

def google_file_service
  @google_file_service
end

#google_vmware_file_serviceGoogle::Apis::VmwareengineV1::GoogleVmwareFileService

Volume message captures user inputs for creation of file services managed by GCVE Corresponds to the JSON property googleVmwareFileService



2654
2655
2656
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2654

def google_vmware_file_service
  @google_vmware_file_service
end

#third_party_file_serviceGoogle::Apis::VmwareengineV1::ThirdPartyFileService

Third party file service configuration Corresponds to the JSON property thirdPartyFileService



2659
2660
2661
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2659

def third_party_file_service
  @third_party_file_service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2666
2667
2668
2669
2670
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2666

def update!(**args)
  @google_file_service = args[:google_file_service] if args.key?(:google_file_service)
  @google_vmware_file_service = args[:google_vmware_file_service] if args.key?(:google_vmware_file_service)
  @third_party_file_service = args[:third_party_file_service] if args.key?(:third_party_file_service)
end