Class: Google::Apis::VmwareengineV1::NodeType
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::NodeType
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Describes node type.
Instance Attribute Summary collapse
-
#available_custom_core_counts ⇒ Array<Fixnum>
Output only.
-
#capabilities ⇒ Array<String>
Output only.
-
#disk_size_gb ⇒ Fixnum
Output only.
-
#display_name ⇒ String
Output only.
-
#families ⇒ Array<String>
Output only.
-
#kind ⇒ String
Output only.
-
#memory_gb ⇒ Fixnum
Output only.
-
#name ⇒ String
Output only.
-
#node_type_id ⇒ String
Output only.
-
#total_core_count ⇒ Fixnum
Output only.
-
#virtual_cpu_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeType
constructor
A new instance of NodeType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeType
Returns a new instance of NodeType.
2846 2847 2848 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2846 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_custom_core_counts ⇒ Array<Fixnum>
Output only. List of possible values of custom core count.
Corresponds to the JSON property availableCustomCoreCounts
2788 2789 2790 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2788 def available_custom_core_counts @available_custom_core_counts end |
#capabilities ⇒ Array<String>
Output only. Capabilities of this node type.
Corresponds to the JSON property capabilities
2793 2794 2795 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2793 def capabilities @capabilities end |
#disk_size_gb ⇒ Fixnum
Output only. The amount of storage available, defined in GB.
Corresponds to the JSON property diskSizeGb
2798 2799 2800 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2798 def disk_size_gb @disk_size_gb end |
#display_name ⇒ String
Output only. The friendly name for this node type. For example: ve1-standard-
72
Corresponds to the JSON property displayName
2804 2805 2806 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2804 def display_name @display_name end |
#families ⇒ Array<String>
Output only. Families of the node type. For node types to be in the same
cluster they must share at least one element in the families.
Corresponds to the JSON property families
2810 2811 2812 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2810 def families @families end |
#kind ⇒ String
Output only. The type of the resource.
Corresponds to the JSON property kind
2815 2816 2817 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2815 def kind @kind end |
#memory_gb ⇒ Fixnum
Output only. The amount of physical memory available, defined in GB.
Corresponds to the JSON property memoryGb
2820 2821 2822 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2820 def memory_gb @memory_gb end |
#name ⇒ String
Output only. The resource name of this node type. Resource names are
schemeless URIs that follow the conventions in https://cloud.google.com/apis/
design/resource_names. For example: projects/my-proj/locations/us-central1-a/
nodeTypes/standard-72
Corresponds to the JSON property name
2828 2829 2830 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2828 def name @name end |
#node_type_id ⇒ String
Output only. The canonical identifier of the node type (corresponds to the
NodeType). For example: standard-72.
Corresponds to the JSON property nodeTypeId
2834 2835 2836 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2834 def node_type_id @node_type_id end |
#total_core_count ⇒ Fixnum
Output only. The total number of CPU cores in a single node.
Corresponds to the JSON property totalCoreCount
2839 2840 2841 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2839 def total_core_count @total_core_count end |
#virtual_cpu_count ⇒ Fixnum
Output only. The total number of virtual CPUs in a single node.
Corresponds to the JSON property virtualCpuCount
2844 2845 2846 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2844 def virtual_cpu_count @virtual_cpu_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 2851 def update!(**args) @available_custom_core_counts = args[:available_custom_core_counts] if args.key?(:available_custom_core_counts) @capabilities = args[:capabilities] if args.key?(:capabilities) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @display_name = args[:display_name] if args.key?(:display_name) @families = args[:families] if args.key?(:families) @kind = args[:kind] if args.key?(:kind) @memory_gb = args[:memory_gb] if args.key?(:memory_gb) @name = args[:name] if args.key?(:name) @node_type_id = args[:node_type_id] if args.key?(:node_type_id) @total_core_count = args[:total_core_count] if args.key?(:total_core_count) @virtual_cpu_count = args[:virtual_cpu_count] if args.key?(:virtual_cpu_count) end |