Class: Google::Apis::VmwareengineV1::PeeringRoute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Exchanged network peering route.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PeeringRoute

Returns a new instance of PeeringRoute.



3094
3095
3096
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dest_rangeString

Output only. Destination range of the peering route in CIDR notation. Corresponds to the JSON property destRange

Returns:

  • (String)


3058
3059
3060
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3058

def dest_range
  @dest_range
end

#directionString

Output only. Direction of the routes exchanged with the peer network, from the VMware Engine network perspective: * Routes of direction INCOMING are imported from the peer network. * Routes of direction OUTGOING are exported from the intranet VPC network of the VMware Engine network. Corresponds to the JSON property direction

Returns:

  • (String)


3066
3067
3068
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3066

def direction
  @direction
end

#importedBoolean Also known as: imported?

Output only. True if the peering route has been imported from a peered VPC network; false otherwise. The import happens if the field NetworkPeering. importCustomRoutes is true for this network, NetworkPeering. exportCustomRoutes is true for the peer VPC network, and the import does not result in a route conflict. Corresponds to the JSON property imported

Returns:

  • (Boolean)


3075
3076
3077
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3075

def imported
  @imported
end

#next_hop_regionString

Output only. Region containing the next hop of the peering route. This field only applies to dynamic routes in the peer VPC network. Corresponds to the JSON property nextHopRegion

Returns:

  • (String)


3082
3083
3084
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3082

def next_hop_region
  @next_hop_region
end

#priorityFixnum

Output only. The priority of the peering route. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


3087
3088
3089
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3087

def priority
  @priority
end

#typeString

Output only. Type of the route in the peer VPC network. Corresponds to the JSON property type

Returns:

  • (String)


3092
3093
3094
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3092

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3099
3100
3101
3102
3103
3104
3105
3106
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3099

def update!(**args)
  @dest_range = args[:dest_range] if args.key?(:dest_range)
  @direction = args[:direction] if args.key?(:direction)
  @imported = args[:imported] if args.key?(:imported)
  @next_hop_region = args[:next_hop_region] if args.key?(:next_hop_region)
  @priority = args[:priority] if args.key?(:priority)
  @type = args[:type] if args.key?(:type)
end