Class: Google::Apis::VmwareengineV1::PeeringRoute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Exchanged network peering route.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PeeringRoute

Returns a new instance of PeeringRoute.



3046
3047
3048
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3046

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dest_rangeString

Output only. Destination range of the peering route in CIDR notation. Corresponds to the JSON property destRange

Returns:

  • (String)


3010
3011
3012
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3010

def dest_range
  @dest_range
end

#directionString

Output only. Direction of the routes exchanged with the peer network, from the VMware Engine network perspective: * Routes of direction INCOMING are imported from the peer network. * Routes of direction OUTGOING are exported from the intranet VPC network of the VMware Engine network. Corresponds to the JSON property direction

Returns:

  • (String)


3018
3019
3020
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3018

def direction
  @direction
end

#importedBoolean Also known as: imported?

Output only. True if the peering route has been imported from a peered VPC network; false otherwise. The import happens if the field NetworkPeering. importCustomRoutes is true for this network, NetworkPeering. exportCustomRoutes is true for the peer VPC network, and the import does not result in a route conflict. Corresponds to the JSON property imported

Returns:

  • (Boolean)


3027
3028
3029
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3027

def imported
  @imported
end

#next_hop_regionString

Output only. Region containing the next hop of the peering route. This field only applies to dynamic routes in the peer VPC network. Corresponds to the JSON property nextHopRegion

Returns:

  • (String)


3034
3035
3036
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3034

def next_hop_region
  @next_hop_region
end

#priorityFixnum

Output only. The priority of the peering route. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


3039
3040
3041
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3039

def priority
  @priority
end

#typeString

Output only. Type of the route in the peer VPC network. Corresponds to the JSON property type

Returns:

  • (String)


3044
3045
3046
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3044

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3051
3052
3053
3054
3055
3056
3057
3058
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3051

def update!(**args)
  @dest_range = args[:dest_range] if args.key?(:dest_range)
  @direction = args[:direction] if args.key?(:direction)
  @imported = args[:imported] if args.key?(:imported)
  @next_hop_region = args[:next_hop_region] if args.key?(:next_hop_region)
  @priority = args[:priority] if args.key?(:priority)
  @type = args[:type] if args.key?(:type)
end