Class: Google::Apis::VmwareengineV1::PrivateCloud

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Represents a private cloud resource. Private clouds of type STANDARD and TIME_LIMITED are zonal resources, STRETCHED private clouds are regional.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivateCloud

Returns a new instance of PrivateCloud.



3262
3263
3264
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3262

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Creation time of this resource. Corresponds to the JSON property createTime

Returns:

  • (String)


3190
3191
3192
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3190

def create_time
  @create_time
end

#delete_timeString

Output only. Time when the resource was scheduled for deletion. Corresponds to the JSON property deleteTime

Returns:

  • (String)


3195
3196
3197
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3195

def delete_time
  @delete_time
end

#descriptionString

User-provided description for this private cloud. Corresponds to the JSON property description

Returns:

  • (String)


3200
3201
3202
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3200

def description
  @description
end

#expire_timeString

Output only. Time when the resource will be irreversibly deleted. Corresponds to the JSON property expireTime

Returns:

  • (String)


3205
3206
3207
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3205

def expire_time
  @expire_time
end

#hcxGoogle::Apis::VmwareengineV1::Hcx

Details about a HCX Cloud Manager appliance. Corresponds to the JSON property hcx



3210
3211
3212
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3210

def hcx
  @hcx
end

#management_clusterGoogle::Apis::VmwareengineV1::ManagementCluster

Management cluster configuration. Corresponds to the JSON property managementCluster



3215
3216
3217
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3215

def management_cluster
  @management_cluster
end

#nameString

Output only. Identifier. The resource name of this private cloud. Resource names are schemeless URIs that follow the conventions in https://cloud.google. com/apis/design/resource_names. For example: projects/my-project/locations/us- central1-a/privateClouds/my-cloud Corresponds to the JSON property name

Returns:

  • (String)


3223
3224
3225
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3223

def name
  @name
end

#network_configGoogle::Apis::VmwareengineV1::NetworkConfig

Network configuration in the consumer project with which the peering has to be done. Corresponds to the JSON property networkConfig



3229
3230
3231
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3229

def network_config
  @network_config
end

#nsxGoogle::Apis::VmwareengineV1::Nsx

Details about a NSX Manager appliance. Corresponds to the JSON property nsx



3234
3235
3236
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3234

def nsx
  @nsx
end

#stateString

Output only. State of the resource. New values may be added to this enum when appropriate. Corresponds to the JSON property state

Returns:

  • (String)


3240
3241
3242
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3240

def state
  @state
end

#typeString

Optional. Type of the private cloud. Defaults to STANDARD. Corresponds to the JSON property type

Returns:

  • (String)


3245
3246
3247
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3245

def type
  @type
end

#uidString

Output only. System-generated unique identifier for the resource. Corresponds to the JSON property uid

Returns:

  • (String)


3250
3251
3252
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3250

def uid
  @uid
end

#update_timeString

Output only. Last update time of this resource. Corresponds to the JSON property updateTime

Returns:

  • (String)


3255
3256
3257
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3255

def update_time
  @update_time
end

#vcenterGoogle::Apis::VmwareengineV1::Vcenter

Details about a vCenter Server management appliance. Corresponds to the JSON property vcenter



3260
3261
3262
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3260

def vcenter
  @vcenter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3267
3268
3269
3270
3271
3272
3273
3274
3275
3276
3277
3278
3279
3280
3281
3282
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3267

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @description = args[:description] if args.key?(:description)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @hcx = args[:hcx] if args.key?(:hcx)
  @management_cluster = args[:management_cluster] if args.key?(:management_cluster)
  @name = args[:name] if args.key?(:name)
  @network_config = args[:network_config] if args.key?(:network_config)
  @nsx = args[:nsx] if args.key?(:nsx)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vcenter = args[:vcenter] if args.key?(:vcenter)
end