Class: Google::Apis::VmwareengineV1::RevokeDnsBindPermissionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Request message for VmwareEngine.RevokeDnsBindPermission

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevokeDnsBindPermissionRequest

Returns a new instance of RevokeDnsBindPermissionRequest.



3522
3523
3524
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#principalGoogle::Apis::VmwareengineV1::Principal

Users/Service accounts which have access for DNS binding on the intranet VPC corresponding to the consumer project. Corresponds to the JSON property principal



3505
3506
3507
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3505

def principal
  @principal
end

#request_idString

Optional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server guarantees that a request doesn't result in creation of duplicate commitments for at least 60 minutes. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000- 0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


3520
3521
3522
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3520

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3527
3528
3529
3530
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3527

def update!(**args)
  @principal = args[:principal] if args.key?(:principal)
  @request_id = args[:request_id] if args.key?(:request_id)
end