Class: Google::Apis::VmwareengineV1::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Schedule for the upgrade.
Instance Attribute Summary collapse
-
#constraints ⇒ Google::Apis::VmwareengineV1::Constraints
Constraints to be applied while editing a schedule.
-
#edit_window ⇒ Google::Apis::VmwareengineV1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#last_editor ⇒ String
Output only.
-
#start_time ⇒ String
Required.
-
#weekly_windows ⇒ Array<Google::Apis::VmwareengineV1::TimeWindow>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
3616 3617 3618 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraints ⇒ Google::Apis::VmwareengineV1::Constraints
Constraints to be applied while editing a schedule. These constraints ensure
that Upgrade specific requirements are met.
Corresponds to the JSON property constraints
3589 3590 3591 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3589 def constraints @constraints end |
#edit_window ⇒ Google::Apis::VmwareengineV1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property editWindow
3597 3598 3599 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3597 def edit_window @edit_window end |
#last_editor ⇒ String
Output only. Output Only. Indicates who most recently edited the upgrade
schedule. The value is updated whenever the upgrade is rescheduled.
Corresponds to the JSON property lastEditor
3603 3604 3605 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3603 def last_editor @last_editor end |
#start_time ⇒ String
Required. The scheduled start time for the upgrade.
Corresponds to the JSON property startTime
3608 3609 3610 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3608 def start_time @start_time end |
#weekly_windows ⇒ Array<Google::Apis::VmwareengineV1::TimeWindow>
Required. Weekly time windows for upgrade activities. The server performs
upgrade activities during these time windows to minimize disruptions.
Corresponds to the JSON property weeklyWindows
3614 3615 3616 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3614 def weekly_windows @weekly_windows end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3621 3622 3623 3624 3625 3626 3627 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3621 def update!(**args) @constraints = args[:constraints] if args.key?(:constraints) @edit_window = args[:edit_window] if args.key?(:edit_window) @last_editor = args[:last_editor] if args.key?(:last_editor) @start_time = args[:start_time] if args.key?(:start_time) @weekly_windows = args[:weekly_windows] if args.key?(:weekly_windows) end |