Class: Google::Apis::VmwareengineV1::Schedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Schedule for the upgrade.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Schedule

Returns a new instance of Schedule.



3568
3569
3570
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constraintsGoogle::Apis::VmwareengineV1::Constraints

Constraints to be applied while editing a schedule. These constraints ensure that Upgrade specific requirements are met. Corresponds to the JSON property constraints



3541
3542
3543
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3541

def constraints
  @constraints
end

#edit_windowGoogle::Apis::VmwareengineV1::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property editWindow



3549
3550
3551
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3549

def edit_window
  @edit_window
end

#last_editorString

Output only. Output Only. Indicates who most recently edited the upgrade schedule. The value is updated whenever the upgrade is rescheduled. Corresponds to the JSON property lastEditor

Returns:

  • (String)


3555
3556
3557
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3555

def last_editor
  @last_editor
end

#start_timeString

Required. The scheduled start time for the upgrade. Corresponds to the JSON property startTime

Returns:

  • (String)


3560
3561
3562
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3560

def start_time
  @start_time
end

#weekly_windowsArray<Google::Apis::VmwareengineV1::TimeWindow>

Required. Weekly time windows for upgrade activities. The server performs upgrade activities during these time windows to minimize disruptions. Corresponds to the JSON property weeklyWindows



3566
3567
3568
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3566

def weekly_windows
  @weekly_windows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3573
3574
3575
3576
3577
3578
3579
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3573

def update!(**args)
  @constraints = args[:constraints] if args.key?(:constraints)
  @edit_window = args[:edit_window] if args.key?(:edit_window)
  @last_editor = args[:last_editor] if args.key?(:last_editor)
  @start_time = args[:start_time] if args.key?(:start_time)
  @weekly_windows = args[:weekly_windows] if args.key?(:weekly_windows)
end