Class: Google::Apis::VmwareengineV1::TimeWindow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Represents the time window to perform upgrade activities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeWindow

Returns a new instance of TimeWindow.



3974
3975
3976
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#day_of_weekString

Required. Day of the week for this window. Corresponds to the JSON property dayOfWeek

Returns:

  • (String)


3959
3960
3961
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3959

def day_of_week
  @day_of_week
end

#durationString

Required. The duration of the window. The max allowed duration for any window is 24 hours. Corresponds to the JSON property duration

Returns:

  • (String)


3965
3966
3967
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3965

def duration
  @duration
end

#start_timeGoogle::Apis::VmwareengineV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



3972
3973
3974
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3972

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3979
3980
3981
3982
3983
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3979

def update!(**args)
  @day_of_week = args[:day_of_week] if args.key?(:day_of_week)
  @duration = args[:duration] if args.key?(:duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end