Class: Google::Apis::VmwareengineV1::TimeWindow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Represents the time window to perform upgrade activities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeWindow

Returns a new instance of TimeWindow.



3926
3927
3928
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3926

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#day_of_weekString

Required. Day of the week for this window. Corresponds to the JSON property dayOfWeek

Returns:

  • (String)


3911
3912
3913
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3911

def day_of_week
  @day_of_week
end

#durationString

Required. The duration of the window. The max allowed duration for any window is 24 hours. Corresponds to the JSON property duration

Returns:

  • (String)


3917
3918
3919
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3917

def duration
  @duration
end

#start_timeGoogle::Apis::VmwareengineV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



3924
3925
3926
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3924

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3931
3932
3933
3934
3935
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3931

def update!(**args)
  @day_of_week = args[:day_of_week] if args.key?(:day_of_week)
  @duration = args[:duration] if args.key?(:duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end