Class: Google::Apis::VmwareengineV1::UnmountDatastoreRequest
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::UnmountDatastoreRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Unmount Datastore Request messag
Instance Attribute Summary collapse
-
#datastore ⇒ String
Required.
-
#request_id ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UnmountDatastoreRequest
constructor
A new instance of UnmountDatastoreRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UnmountDatastoreRequest
Returns a new instance of UnmountDatastoreRequest.
3983 3984 3985 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3983 def initialize(**args) update!(**args) end |
Instance Attribute Details
#datastore ⇒ String
Required. The resource name of the datastore to unmount. Resource names are
schemeless URIs that follow the conventions in https://cloud.google.com/apis/
design/resource_names. For example: projects/my-project/locations/us-central1/
datastores/my-datastore
Corresponds to the JSON property datastore
3968 3969 3970 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3968 def datastore @datastore end |
#request_id ⇒ String
Optional. The request ID must be a valid UUID with the exception that zero
UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
3974 3975 3976 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3974 def request_id @request_id end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set to true, only validates the request but doesn’t execute the
request. If set to false, validates and executes the request.
Corresponds to the JSON property validateOnly
3980 3981 3982 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3980 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3988 3989 3990 3991 3992 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 3988 def update!(**args) @datastore = args[:datastore] if args.key?(:datastore) @request_id = args[:request_id] if args.key?(:request_id) @validate_only = args[:validate_only] if args.key?(:validate_only) end |