Class: Google::Apis::VmwareengineV1::Upgrade

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Describes Private cloud Upgrade.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Upgrade

Returns a new instance of Upgrade.



4132
4133
4134
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4132

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#component_upgradesArray<Google::Apis::VmwareengineV1::VmwareUpgradeComponent>

Output only. Output Only. The list of component upgrades. Corresponds to the JSON property componentUpgrades



4050
4051
4052
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4050

def component_upgrades
  @component_upgrades
end

#create_timeString

Output only. Output Only. Creation time of this resource. Corresponds to the JSON property createTime

Returns:

  • (String)


4055
4056
4057
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4055

def create_time
  @create_time
end

#descriptionString

Output only. Output Only. The description of the upgrade. This is used to provide additional information about the private cloud upgrade, such as the upgrade's purpose, the changes included in the upgrade, or any other relevant information about the upgrade. Corresponds to the JSON property description

Returns:

  • (String)


4063
4064
4065
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4063

def description
  @description
end

#end_timeString

Output only. Output Only. End time of the upgrade. Corresponds to the JSON property endTime

Returns:

  • (String)


4068
4069
4070
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4068

def end_time
  @end_time
end

#estimated_durationString

Output only. Output Only. The estimated total duration of the upgrade. This information can be used to plan or schedule upgrades to minimize disruptions. Please note that the estimated duration is only an estimate. The actual upgrade duration may vary. Corresponds to the JSON property estimatedDuration

Returns:

  • (String)


4076
4077
4078
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4076

def estimated_duration
  @estimated_duration
end

#etagString

The etag for the upgrade resource. If this is provided on update, it must match the server's etag. Corresponds to the JSON property etag

Returns:

  • (String)


4082
4083
4084
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4082

def etag
  @etag
end

#nameString

Output only. Identifier. The resource name of the private cloud Upgrade. Resource names are schemeless URIs that follow the conventions in https:// cloud.google.com/apis/design/resource_names. For example: projects/my-project/ locations/us-west1-a/privateClouds/my-cloud/upgrades/my-upgrade Corresponds to the JSON property name

Returns:

  • (String)


4090
4091
4092
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4090

def name
  @name
end

#scheduleGoogle::Apis::VmwareengineV1::Schedule

Schedule for the upgrade. Corresponds to the JSON property schedule



4095
4096
4097
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4095

def schedule
  @schedule
end

#start_versionString

Output only. Output Only. The start version Corresponds to the JSON property startVersion

Returns:

  • (String)


4100
4101
4102
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4100

def start_version
  @start_version
end

#stateString

Output only. The current state of the upgrade. Corresponds to the JSON property state

Returns:

  • (String)


4105
4106
4107
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4105

def state
  @state
end

#target_versionString

Output only. Output Only. The target version Corresponds to the JSON property targetVersion

Returns:

  • (String)


4110
4111
4112
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4110

def target_version
  @target_version
end

#typeString

Output only. Output Only. The type of upgrade. Corresponds to the JSON property type

Returns:

  • (String)


4115
4116
4117
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4115

def type
  @type
end

#uidString

Output only. System-generated unique identifier for the resource. Corresponds to the JSON property uid

Returns:

  • (String)


4120
4121
4122
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4120

def uid
  @uid
end

#update_timeString

Output only. Output Only. Last update time of this resource. Corresponds to the JSON property updateTime

Returns:

  • (String)


4125
4126
4127
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4125

def update_time
  @update_time
end

#versionString

Output only. Corresponds to the JSON property version

Returns:

  • (String)


4130
4131
4132
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4130

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4137
4138
4139
4140
4141
4142
4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4137

def update!(**args)
  @component_upgrades = args[:component_upgrades] if args.key?(:component_upgrades)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @end_time = args[:end_time] if args.key?(:end_time)
  @estimated_duration = args[:estimated_duration] if args.key?(:estimated_duration)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @schedule = args[:schedule] if args.key?(:schedule)
  @start_version = args[:start_version] if args.key?(:start_version)
  @state = args[:state] if args.key?(:state)
  @target_version = args[:target_version] if args.key?(:target_version)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version = args[:version] if args.key?(:version)
end