Class: Google::Apis::VmwareengineV1::Upgrade
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::Upgrade
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Describes Private cloud Upgrade.
Instance Attribute Summary collapse
-
#component_upgrades ⇒ Array<Google::Apis::VmwareengineV1::VmwareUpgradeComponent>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#estimated_duration ⇒ String
Output only.
-
#etag ⇒ String
The etag for the upgrade resource.
-
#name ⇒ String
Output only.
-
#schedule ⇒ Google::Apis::VmwareengineV1::Schedule
Schedule for the upgrade.
-
#start_version ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#target_version ⇒ String
Output only.
-
#type ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Upgrade
constructor
A new instance of Upgrade.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Upgrade
Returns a new instance of Upgrade.
4132 4133 4134 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4132 def initialize(**args) update!(**args) end |
Instance Attribute Details
#component_upgrades ⇒ Array<Google::Apis::VmwareengineV1::VmwareUpgradeComponent>
Output only. Output Only. The list of component upgrades.
Corresponds to the JSON property componentUpgrades
4050 4051 4052 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4050 def component_upgrades @component_upgrades end |
#create_time ⇒ String
Output only. Output Only. Creation time of this resource.
Corresponds to the JSON property createTime
4055 4056 4057 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4055 def create_time @create_time end |
#description ⇒ String
Output only. Output Only. The description of the upgrade. This is used to
provide additional information about the private cloud upgrade, such as the
upgrade's purpose, the changes included in the upgrade, or any other relevant
information about the upgrade.
Corresponds to the JSON property description
4063 4064 4065 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4063 def description @description end |
#end_time ⇒ String
Output only. Output Only. End time of the upgrade.
Corresponds to the JSON property endTime
4068 4069 4070 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4068 def end_time @end_time end |
#estimated_duration ⇒ String
Output only. Output Only. The estimated total duration of the upgrade. This
information can be used to plan or schedule upgrades to minimize disruptions.
Please note that the estimated duration is only an estimate. The actual
upgrade duration may vary.
Corresponds to the JSON property estimatedDuration
4076 4077 4078 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4076 def estimated_duration @estimated_duration end |
#etag ⇒ String
The etag for the upgrade resource. If this is provided on update, it must
match the server's etag.
Corresponds to the JSON property etag
4082 4083 4084 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4082 def etag @etag end |
#name ⇒ String
Output only. Identifier. The resource name of the private cloud Upgrade.
Resource names are schemeless URIs that follow the conventions in https://
cloud.google.com/apis/design/resource_names. For example: projects/my-project/
locations/us-west1-a/privateClouds/my-cloud/upgrades/my-upgrade
Corresponds to the JSON property name
4090 4091 4092 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4090 def name @name end |
#schedule ⇒ Google::Apis::VmwareengineV1::Schedule
Schedule for the upgrade.
Corresponds to the JSON property schedule
4095 4096 4097 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4095 def schedule @schedule end |
#start_version ⇒ String
Output only. Output Only. The start version
Corresponds to the JSON property startVersion
4100 4101 4102 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4100 def start_version @start_version end |
#state ⇒ String
Output only. The current state of the upgrade.
Corresponds to the JSON property state
4105 4106 4107 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4105 def state @state end |
#target_version ⇒ String
Output only. Output Only. The target version
Corresponds to the JSON property targetVersion
4110 4111 4112 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4110 def target_version @target_version end |
#type ⇒ String
Output only. Output Only. The type of upgrade.
Corresponds to the JSON property type
4115 4116 4117 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4115 def type @type end |
#uid ⇒ String
Output only. System-generated unique identifier for the resource.
Corresponds to the JSON property uid
4120 4121 4122 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4120 def uid @uid end |
#update_time ⇒ String
Output only. Output Only. Last update time of this resource.
Corresponds to the JSON property updateTime
4125 4126 4127 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4125 def update_time @update_time end |
#version ⇒ String
Output only.
Corresponds to the JSON property version
4130 4131 4132 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4130 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 4150 4151 4152 4153 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4137 def update!(**args) @component_upgrades = args[:component_upgrades] if args.key?(:component_upgrades) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @end_time = args[:end_time] if args.key?(:end_time) @estimated_duration = args[:estimated_duration] if args.key?(:estimated_duration) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @schedule = args[:schedule] if args.key?(:schedule) @start_version = args[:start_version] if args.key?(:start_version) @state = args[:state] if args.key?(:state) @target_version = args[:target_version] if args.key?(:target_version) @type = args[:type] if args.key?(:type) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @version = args[:version] if args.key?(:version) end |