Class: Google::Apis::VmwareengineV1::Upgrade
- Inherits:
-
Object
- Object
- Google::Apis::VmwareengineV1::Upgrade
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb
Overview
Describes Private cloud Upgrade.
Instance Attribute Summary collapse
-
#component_upgrades ⇒ Array<Google::Apis::VmwareengineV1::VmwareUpgradeComponent>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#estimated_duration ⇒ String
Output only.
-
#etag ⇒ String
The etag for the upgrade resource.
-
#name ⇒ String
Output only.
-
#schedule ⇒ Google::Apis::VmwareengineV1::Schedule
Schedule for the upgrade.
-
#start_version ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#target_version ⇒ String
Output only.
-
#type ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Upgrade
constructor
A new instance of Upgrade.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Upgrade
Returns a new instance of Upgrade.
4084 4085 4086 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4084 def initialize(**args) update!(**args) end |
Instance Attribute Details
#component_upgrades ⇒ Array<Google::Apis::VmwareengineV1::VmwareUpgradeComponent>
Output only. Output Only. The list of component upgrades.
Corresponds to the JSON property componentUpgrades
4002 4003 4004 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4002 def component_upgrades @component_upgrades end |
#create_time ⇒ String
Output only. Output Only. Creation time of this resource.
Corresponds to the JSON property createTime
4007 4008 4009 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4007 def create_time @create_time end |
#description ⇒ String
Output only. Output Only. The description of the upgrade. This is used to
provide additional information about the private cloud upgrade, such as the
upgrade's purpose, the changes included in the upgrade, or any other relevant
information about the upgrade.
Corresponds to the JSON property description
4015 4016 4017 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4015 def description @description end |
#end_time ⇒ String
Output only. Output Only. End time of the upgrade.
Corresponds to the JSON property endTime
4020 4021 4022 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4020 def end_time @end_time end |
#estimated_duration ⇒ String
Output only. Output Only. The estimated total duration of the upgrade. This
information can be used to plan or schedule upgrades to minimize disruptions.
Please note that the estimated duration is only an estimate. The actual
upgrade duration may vary.
Corresponds to the JSON property estimatedDuration
4028 4029 4030 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4028 def estimated_duration @estimated_duration end |
#etag ⇒ String
The etag for the upgrade resource. If this is provided on update, it must
match the server's etag.
Corresponds to the JSON property etag
4034 4035 4036 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4034 def etag @etag end |
#name ⇒ String
Output only. Identifier. The resource name of the private cloud Upgrade.
Resource names are schemeless URIs that follow the conventions in https://
cloud.google.com/apis/design/resource_names. For example: projects/my-project/
locations/us-west1-a/privateClouds/my-cloud/upgrades/my-upgrade
Corresponds to the JSON property name
4042 4043 4044 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4042 def name @name end |
#schedule ⇒ Google::Apis::VmwareengineV1::Schedule
Schedule for the upgrade.
Corresponds to the JSON property schedule
4047 4048 4049 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4047 def schedule @schedule end |
#start_version ⇒ String
Output only. Output Only. The start version
Corresponds to the JSON property startVersion
4052 4053 4054 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4052 def start_version @start_version end |
#state ⇒ String
Output only. The current state of the upgrade.
Corresponds to the JSON property state
4057 4058 4059 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4057 def state @state end |
#target_version ⇒ String
Output only. Output Only. The target version
Corresponds to the JSON property targetVersion
4062 4063 4064 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4062 def target_version @target_version end |
#type ⇒ String
Output only. Output Only. The type of upgrade.
Corresponds to the JSON property type
4067 4068 4069 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4067 def type @type end |
#uid ⇒ String
Output only. System-generated unique identifier for the resource.
Corresponds to the JSON property uid
4072 4073 4074 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4072 def uid @uid end |
#update_time ⇒ String
Output only. Output Only. Last update time of this resource.
Corresponds to the JSON property updateTime
4077 4078 4079 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4077 def update_time @update_time end |
#version ⇒ String
Output only.
Corresponds to the JSON property version
4082 4083 4084 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4082 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 |
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4089 def update!(**args) @component_upgrades = args[:component_upgrades] if args.key?(:component_upgrades) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @end_time = args[:end_time] if args.key?(:end_time) @estimated_duration = args[:estimated_duration] if args.key?(:estimated_duration) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @schedule = args[:schedule] if args.key?(:schedule) @start_version = args[:start_version] if args.key?(:start_version) @state = args[:state] if args.key?(:state) @target_version = args[:target_version] if args.key?(:target_version) @type = args[:type] if args.key?(:type) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @version = args[:version] if args.key?(:version) end |