Class: Google::Apis::VmwareengineV1::VmwareEngineNetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

VMware Engine network resource that provides connectivity for VMware Engine private clouds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmwareEngineNetwork

Returns a new instance of VmwareEngineNetwork.



4202
4203
4204
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4202

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Creation time of this resource. Corresponds to the JSON property createTime

Returns:

  • (String)


4153
4154
4155
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4153

def create_time
  @create_time
end

#descriptionString

User-provided description for this VMware Engine network. Corresponds to the JSON property description

Returns:

  • (String)


4158
4159
4160
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4158

def description
  @description
end

#etagString

Checksum that may be sent on update and delete requests to ensure that the user-provided value is up to date before the server processes a request. The server computes checksums based on the value of other fields in the request. Corresponds to the JSON property etag

Returns:

  • (String)


4165
4166
4167
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4165

def etag
  @etag
end

#nameString

Output only. Identifier. The resource name of the VMware Engine network. Resource names are schemeless URIs that follow the conventions in https:// cloud.google.com/apis/design/resource_names. For example: projects/my-project/ locations/global/vmwareEngineNetworks/my-network Corresponds to the JSON property name

Returns:

  • (String)


4173
4174
4175
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4173

def name
  @name
end

#stateString

Output only. State of the VMware Engine network. Corresponds to the JSON property state

Returns:

  • (String)


4178
4179
4180
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4178

def state
  @state
end

#typeString

Required. VMware Engine network type. Corresponds to the JSON property type

Returns:

  • (String)


4183
4184
4185
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4183

def type
  @type
end

#uidString

Output only. System-generated unique identifier for the resource. Corresponds to the JSON property uid

Returns:

  • (String)


4188
4189
4190
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4188

def uid
  @uid
end

#update_timeString

Output only. Last update time of this resource. Corresponds to the JSON property updateTime

Returns:

  • (String)


4193
4194
4195
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4193

def update_time
  @update_time
end

#vpc_networksArray<Google::Apis::VmwareengineV1::VpcNetwork>

Output only. VMware Engine service VPC networks that provide connectivity from a private cloud to customer projects, the internet, and other Google Cloud services. Corresponds to the JSON property vpcNetworks



4200
4201
4202
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4200

def vpc_networks
  @vpc_networks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4207
4208
4209
4210
4211
4212
4213
4214
4215
4216
4217
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4207

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vpc_networks = args[:vpc_networks] if args.key?(:vpc_networks)
end