Class: Google::Apis::VmwareengineV1::WeeklyTimeInterval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Represents a time interval, spanning across days of the week. Until local timezones are supported, this interval is in UTC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WeeklyTimeInterval

Returns a new instance of WeeklyTimeInterval.



4350
4351
4352
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_dayString

Output only. The day on which the interval ends. Can be same as start day. Corresponds to the JSON property endDay

Returns:

  • (String)


4329
4330
4331
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4329

def end_day
  @end_day
end

#end_timeGoogle::Apis::VmwareengineV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property endTime



4336
4337
4338
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4336

def end_time
  @end_time
end

#start_dayString

Output only. The day on which the interval starts. Corresponds to the JSON property startDay

Returns:

  • (String)


4341
4342
4343
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4341

def start_day
  @start_day
end

#start_timeGoogle::Apis::VmwareengineV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



4348
4349
4350
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4348

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4355
4356
4357
4358
4359
4360
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4355

def update!(**args)
  @end_day = args[:end_day] if args.key?(:end_day)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_day = args[:start_day] if args.key?(:start_day)
  @start_time = args[:start_time] if args.key?(:start_time)
end