Class: Google::Apis::VmwareengineV1::WeeklyTimeInterval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmwareengine_v1/classes.rb,
lib/google/apis/vmwareengine_v1/representations.rb,
lib/google/apis/vmwareengine_v1/representations.rb

Overview

Represents a time interval, spanning across days of the week. Until local timezones are supported, this interval is in UTC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WeeklyTimeInterval

Returns a new instance of WeeklyTimeInterval.



4302
4303
4304
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4302

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_dayString

Output only. The day on which the interval ends. Can be same as start day. Corresponds to the JSON property endDay

Returns:

  • (String)


4281
4282
4283
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4281

def end_day
  @end_day
end

#end_timeGoogle::Apis::VmwareengineV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property endTime



4288
4289
4290
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4288

def end_time
  @end_time
end

#start_dayString

Output only. The day on which the interval starts. Corresponds to the JSON property startDay

Returns:

  • (String)


4293
4294
4295
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4293

def start_day
  @start_day
end

#start_timeGoogle::Apis::VmwareengineV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



4300
4301
4302
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4300

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4307
4308
4309
4310
4311
4312
# File 'lib/google/apis/vmwareengine_v1/classes.rb', line 4307

def update!(**args)
  @end_day = args[:end_day] if args.key?(:end_day)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_day = args[:start_day] if args.key?(:start_day)
  @start_time = args[:start_time] if args.key?(:start_time)
end